_id
stringlengths
64
64
repository
stringlengths
6
84
name
stringlengths
4
110
content
stringlengths
0
248k
license
null
download_url
stringlengths
89
454
language
stringclasses
7 values
comments
stringlengths
0
74.6k
code
stringlengths
0
248k
9a71ef8486ce7c68eea14d5ba4c1cc1eaf8e1d162afc88766eec74572fd3be29
hammerlab/genspio
common.ml
include Base module Unique_name = struct let x = ref 0 let create prefix = Caml.incr x ; Fmt.str "%s_%d_%d" prefix !x (Random.int 100_000) let variable = create end let with_buffer ?(size = 42) f = let b = Buffer.create size in let str = Buffer.add_string b in let res = f str in (Buffer.conten...
null
https://raw.githubusercontent.com/hammerlab/genspio/f270fb296cebcf25e2ea89a7929a274c03ae9e6e/src/lib/common.ml
ocaml
include Base module Unique_name = struct let x = ref 0 let create prefix = Caml.incr x ; Fmt.str "%s_%d_%d" prefix !x (Random.int 100_000) let variable = create end let with_buffer ?(size = 42) f = let b = Buffer.create size in let str = Buffer.add_string b in let res = f str in (Buffer.conten...
c06aead475aa95e44b12ef0b9294e1617c8fc9857877d6fc35c5c9f993682fe7
themattchan/lamb
Checker.hs
# LANGUAGE FlexibleContexts # -------------------------------------------------------------------------------- -- | This module contains the code for converting an `Expr` to a "A-Normal" form. -------------------------------------------------------------------------------- module Language.Lamb.Checker * Top - level ...
null
https://raw.githubusercontent.com/themattchan/lamb/26d7e0176ab642fe47d3f000f2f3c4e48519e669/lib/Language/Lamb/Checker.hs
haskell
------------------------------------------------------------------------------ | This module contains the code for converting an `Expr` to a "A-Normal" form. ------------------------------------------------------------------------------ * Error Constructors ------------------------------------------------------------...
# LANGUAGE FlexibleContexts # module Language.Lamb.Checker * Top - level Static Checker check , errUnboundVar , errUnboundFun ) where import Control.Exception import qualified Data.List as L import Text.Printf (printf) import Language.Lamb.Types import ...
427d8e6a580683ab4320a271b6be9bb453de980a5c75b6bac1de086a5d9b1d2e
andreas/ocaml-graphql-server
directives_test.ml
let test_query = Test_common.test_query Test_schema.schema () let suite = [ ( "skip directive", `Quick, fun () -> let query = "{ users { id @skip(if: true) name } }" in test_query query (`Assoc [ ( "data", `Assoc [ ...
null
https://raw.githubusercontent.com/andreas/ocaml-graphql-server/d615cbb164d4ddfdc2efeb246a198dfe114adf24/graphql/test/directives_test.ml
ocaml
* Per the link below, the field "must be queried only if the @skip * condition is false and the @include condition is true". * /#sec--include /#example-77377
let test_query = Test_common.test_query Test_schema.schema () let suite = [ ( "skip directive", `Quick, fun () -> let query = "{ users { id @skip(if: true) name } }" in test_query query (`Assoc [ ( "data", `Assoc [ ...
b408e5300d8df30635bcbf3c39d9f68c9b572ddace6a94abba03de6b1d6a39a5
larcenists/larceny
peval.scm
PEVAL -- A simple partial evaluator for Scheme , written by . (import (scheme base) (scheme cxr) (scheme read) (scheme write) (scheme time)) ;------------------------------------------------------------------------------ Utilities (define (every? pred? l) (let loop ((l l)) ...
null
https://raw.githubusercontent.com/larcenists/larceny/fef550c7d3923deb7a5a1ccd5a628e54cf231c75/test/Benchmarking/R7RS/src/peval.scm
scheme
------------------------------------------------------------------------------ ------------------------------------------------------------------------------ The partial evaluator. return a copy of 'exp' where each bound var has been renamed (to prevent aliasing problems) is 'expr' a constant expression? return t...
PEVAL -- A simple partial evaluator for Scheme , written by . (import (scheme base) (scheme cxr) (scheme read) (scheme write) (scheme time)) Utilities (define (every? pred? l) (let loop ((l l)) (or (null? l) (and (pred? (car l)) (loop (cdr l)))))) (define (some? pred? ...
0c18ea86e43838a8d3260bafcebaf8207d0de4a3d9f1e988246db50492a51a55
helium/packet-purchaser
semtech_udp.erl
%%%------------------------------------------------------------------- %% @doc = = Semtech basic communication protocol between gateway and server = = See -net/packet_forwarder/blob/master/PROTOCOL.TXT %% @end %%%------------------------------------------------------------------- -module(semtech_udp). -include("s...
null
https://raw.githubusercontent.com/helium/packet-purchaser/a23ec2b57acf84dd5f3ae016d94d332f22568aa4/src/semtech_udp/semtech_udp.erl
erlang
------------------------------------------------------------------- @doc @end ------------------------------------------------------------------- ------------------------------------------------------------------- @doc That packet type is used by the gateway mainly to forward the RF packets received, and associate...
= = Semtech basic communication protocol between gateway and server = = See -net/packet_forwarder/blob/master/PROTOCOL.TXT -module(semtech_udp). -include("semtech_udp.hrl"). -export([ push_data/3, push_data/4, push_ack/1, pull_data/2, pull_ack/1, pull_resp/2, tx_ack/2, tx_ack/3, token...
8882d4e08dfb0a964b788ca1b3973be940335c1cfd3a04a2d3b295688780cecc
weavejester/codox
project.clj
(defproject codox "0.10.8" :description "Generate documentation from Clojure source files" :url "" :scm {:dir ".."} :license {:name "Eclipse Public License" :url "-v10.html"} :dependencies [[org.clojure/clojure "1.7.0"] [org.clojure/tools.namespace "0.2.11"] [org....
null
https://raw.githubusercontent.com/weavejester/codox/0313832eb17339ffcb60003ee0c3af149bbf1cb9/codox/project.clj
clojure
(defproject codox "0.10.8" :description "Generate documentation from Clojure source files" :url "" :scm {:dir ".."} :license {:name "Eclipse Public License" :url "-v10.html"} :dependencies [[org.clojure/clojure "1.7.0"] [org.clojure/tools.namespace "0.2.11"] [org....
e21970e4e73cd4722c88ed51988eecd36209b3826ed65388b52780a3f2b33c5b
fortytools/holumbus
Extract.hs
-- ---------------------------------------------------------------------------- | Module : Extract Maintainer : , , , Stability : experimental Portability : portable Helper functions and arrows for building the index . Module : Extract Maintainer : Thorben Guelck, T...
null
https://raw.githubusercontent.com/fortytools/holumbus/4b2f7b832feab2715a4d48be0b07dca018eaa8e8/W3W/src/Extract.hs
haskell
---------------------------------------------------------------------------- ---------------------------------------------------------------------------- ---------------------------------------------------------------------------- | Extract text of all h1-h6 tags. --------------------------------------------------...
| Module : Extract Maintainer : , , , Stability : experimental Portability : portable Helper functions and arrows for building the index . Module : Extract Maintainer : Thorben Guelck, Tobias Lueders, Mathias Leonhardt, Uwe Schmidt Stability : experimental Port...
70a4c2a2354a6a1b07737692fe002196785452e1a1268db209de8d51ac3f85a0
igorhvr/bedlam
SXPath-code.scm
; XML processing in Scheme ; SXPath -- SXML Query Language ; SXPath is a query language for SXML , an instance of XML Information set ( Infoset ) in the form of s - expressions . See for the definition of SXML and more details . SXPath is also a translation into Scheme of an XML Path Language , : ; ...
null
https://raw.githubusercontent.com/igorhvr/bedlam/b62e0d047105bb0473bdb47c58b23f6ca0f79a4e/siscweb/siscweb-src-0.5/opt/sxml/scm/ssax/SXPath-code.scm
scheme
XML processing in Scheme SXPath -- SXML Query Language or their properties. tree, and introduces important notions of a location path and a current, context node. A location path denotes a selection of a set of root node -- which serves as the context node for absolute location paths. Location path i...
SXPath is a query language for SXML , an instance of XML Information set ( Infoset ) in the form of s - expressions . See for the definition of SXML and more details . SXPath is also a translation into Scheme of an XML Path Language , : XPath and SXPath describe means of selecting a set of Infoset 's items ...
6b84b0bb90a9a94eb2fc23104adadaea607db1add592bed0605cf594e314bae8
waldheinz/bling
LightTracer.hs
module Graphics.Bling.Renderer.LightTracer ( LightTracer, mkLightTracer ) where import Control.Monad import Control.Monad.ST import qualified Text.PrettyPrint as PP import Graphics.Bling.Camera import Graphics.Bling.DifferentialGeometry import Graphics.Bling.Image import Graphics.Bling.Primitive import Graph...
null
https://raw.githubusercontent.com/waldheinz/bling/1f338f4b8dbd6a2708cb10787f4a2ac55f66d5a8/src/lib/Graphics/Bling/Renderer/LightTracer.hs
haskell
# UNPACK # ^ photons per pass ^ photons per pass ^ depth nothing hit, terminate path
module Graphics.Bling.Renderer.LightTracer ( LightTracer, mkLightTracer ) where import Control.Monad import Control.Monad.ST import qualified Text.PrettyPrint as PP import Graphics.Bling.Camera import Graphics.Bling.DifferentialGeometry import Graphics.Bling.Image import Graphics.Bling.Primitive import Graph...
2864a7a716d1ebfa94926a14cb17beee474ad7bd077e3a1d5bee2203d201f8af
Bogdanp/koyo
l10n.rkt
#lang racket/base (require gregor racket/contract racket/match racket/string srfi/29 web-server/http "contract.rkt" "profiler.rkt" "session.rkt") Translate ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ...
null
https://raw.githubusercontent.com/Bogdanp/koyo/c544b1eb6746c0ef7b69725f2478c841487b9396/koyo-lib/koyo/l10n.rkt
racket
; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ;
#lang racket/base (require gregor racket/contract racket/match racket/string srfi/29 web-server/http "contract.rkt" "profiler.rkt" "session.rkt") (provide current-locale-specifier current-locales load-locales! translate localize-date) (de...
5a254bf924c95bdfa347a1c852941bb69c3c840e352a5032c261ade5d146411b
ucsd-progsys/liquidhaskell
Bag.hs
{-@ LIQUID "--expect-any-error" @-} module Bag where import qualified Data.Set as S import Language.Haskell.Liquid.Bag as B @ zorg : : { v : B.Bag Int | v = B.empty } @ zorg :: B.Bag Int zorg = B.empty @ measure elems @ elems :: (Ord a) => [a] -> B.Bag a elems [] = B.empty elems (x:x...
null
https://raw.githubusercontent.com/ucsd-progsys/liquidhaskell/f46dbafd6ce1f61af5b56f31924c21639c982a8a/tests/measure/neg/Bag.hs
haskell
@ LIQUID "--expect-any-error" @ @ prop0 :: x:_ -> TT @ @ prop2 :: x:_ -> y:_ -> TT @
module Bag where import qualified Data.Set as S import Language.Haskell.Liquid.Bag as B @ zorg : : { v : B.Bag Int | v = B.empty } @ zorg :: B.Bag Int zorg = B.empty @ measure elems @ elems :: (Ord a) => [a] -> B.Bag a elems [] = B.empty elems (x:xs) = B.put x (elems xs) prop0 :: In...
1504d0b14738b4c7589b4df529bfb33fea67f6b4daf357e132f611550d983f20
clojure/core.typed
binding.clj
(ns clojure.core.typed.test.binding (:require [clojure.core.typed :as t])) (t/def ^:dynamic *foo* :- Boolean, true) (binding [*foo* false])
null
https://raw.githubusercontent.com/clojure/core.typed/f5b7d00bbb29d09000d7fef7cca5b40416c9fa91/typed/checker.jvm/test/clojure/core/typed/test/binding.clj
clojure
(ns clojure.core.typed.test.binding (:require [clojure.core.typed :as t])) (t/def ^:dynamic *foo* :- Boolean, true) (binding [*foo* false])
fc436aff025ade3b3372f1ce20b977f914c7109a7bd61cc4f4a279aecbca8263
opencog/opencog
surface-realization.scm
Links relex - to - logic output with ; ; Test sentence : "This is a sentence." ; modules needed for call-with-input-file and get-string-all ; (use-modules (rnrs io ports)) ( use - modules ( ice-9 rdelim ) ) (use-modules (srfi srfi-1) ; needed for delete-duplicates ( ice-9 threads ) ; needed for par - m...
null
https://raw.githubusercontent.com/opencog/opencog/482a93b34c2eeaac0e773731d61c31558710f93d/opencog/nlp/sureal/surface-realization.scm
scheme
Test sentence : "This is a sentence." modules needed for call-with-input-file and get-string-all (use-modules (rnrs io ports)) needed for delete-duplicates needed for par - map (use-modules (opencog logger)) --------------------------------------------------------------------- Creates a single list made of t...
Links relex - to - logic output with ( use - modules ( ice-9 rdelim ) ) (ice-9 rdelim) (ice-9 regex) (ice-9 receive)) (use-modules (opencog)) (use-modules (opencog exec)) (use-modules (opencog nlp) (opencog nlp oc) (opencog nlp lg-dict) (opencog nlp relex2...
80482680387427a2f66435bf93676dede3cc45d0c2d784587327222bd076c9c2
aria42/infer
lsh_test.clj
(ns infer.lsh-test (:use infer.lsh) (:use clojure.test)) (deftest test-dot-product (is (= 100 (dot-product [5 5 5 5] [5 5 5 5])))) (deftest basic-exact-minhash (let [perm-dict-1 {3 0, 2 1, 1 2, 0 3} perm-dict-2 {3 2, 2 1, 1 0, 0 3} p1 #{1 3} p2 #{3 2}] (is (= 0 ((exact-minhash perm-dict-1) p1))) (is ...
null
https://raw.githubusercontent.com/aria42/infer/9849325a27770794b91415592a8706fd90777469/test/infer/lsh_test.clj
clojure
(ns infer.lsh-test (:use infer.lsh) (:use clojure.test)) (deftest test-dot-product (is (= 100 (dot-product [5 5 5 5] [5 5 5 5])))) (deftest basic-exact-minhash (let [perm-dict-1 {3 0, 2 1, 1 2, 0 3} perm-dict-2 {3 2, 2 1, 1 0, 0 3} p1 #{1 3} p2 #{3 2}] (is (= 0 ((exact-minhash perm-dict-1) p1))) (is ...
500c1dbf29aed0abbd7fd4222323b6c7093515c297309972fb02e4c31f3b3b4b
PapenfussLab/bioshake
FREEC.hs
{-# LANGUAGE FlexibleContexts #-} # LANGUAGE FlexibleInstances # # LANGUAGE MultiParamTypeClasses # {-# LANGUAGE TemplateHaskell #-} module Bioshake.FREEC where import Bioshake import Bioshake.Internal.FREEC import Bioshake.TH import Data.List import De...
null
https://raw.githubusercontent.com/PapenfussLab/bioshake/afeb7219b171e242b6e9bb9e99e2f80c0a099aff/Bioshake/FREEC.hs
haskell
# LANGUAGE FlexibleContexts # # LANGUAGE TemplateHaskell #
# LANGUAGE FlexibleInstances # # LANGUAGE MultiParamTypeClasses # module Bioshake.FREEC where import Bioshake import Bioshake.Internal.FREEC import Bioshake.TH import Data.List import Development.Shake import Development.Shake.FilePath $(makeThreaded ''...
8ae56e4d4d82cdb88a655f29413e3c5d263a97c3fc9be681f213e1c613b4aa22
erlyaws/yaws
yaws_dynopts.erl
-module(yaws_dynopts). -include("../include/yaws.hrl"). -include("../include/yaws_api.hrl"). -export([ have_http_uri_parse/0, have_safe_relative_path/0, http_uri_parse/1, safe_relative_path/2, start_error_logger/0, generate/1, purge_old_code/0, ...
null
https://raw.githubusercontent.com/erlyaws/yaws/b49e75dc81fa3312542fcee886a2b94288e75608/src/yaws_dynopts.erl
erlang
This will never happen, but fallback if it happens anyway. This will never happen, but fallback if it happens anyway. For last digit ignore everything after the "-", if any For last digit ignore everything after the "-", if any For last digit ignore everything after the "-", if any %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%...
-module(yaws_dynopts). -include("../include/yaws.hrl"). -include("../include/yaws_api.hrl"). -export([ have_http_uri_parse/0, have_safe_relative_path/0, http_uri_parse/1, safe_relative_path/2, start_error_logger/0, generate/1, purge_old_code/0, ...
195080e669c9750235e9486453c147c84c71fa3d3d85e1c152bafa357b076830
racket/compatibility
package.rkt
#lang racket/base (require (for-syntax racket/base syntax/define syntax/boundmap racket/pretty)) (provide define-package package-begin open-package open*-package define* define*-values define*-syntax ...
null
https://raw.githubusercontent.com/racket/compatibility/492030dac6f095045ce8a13dca75204dd5f34e32/compatibility-lib/compatibility/package.rkt
racket
For permission to move scopes from a definition in a package to a binding of the identifier when the package is opened: ---------------------------------------- Add another scope layer: Remove star layers: sync with above adjustments to `new-def-id` Make sure that a name is not defined with `define` if there's ...
#lang racket/base (require (for-syntax racket/base syntax/define syntax/boundmap racket/pretty)) (provide define-package package-begin open-package open*-package define* define*-values define*-syntax ...
c6a7824b828c8db1e0e521c77cdb2192d770dd1647b3ed25bd4a58b579fc2eb9
squaresLab/footpatch
patch.mli
type t (** A patch is a change bound to a file. Possible indentation is applied to the change. *) val create: ?indent:Indent.t -> ?replace:bool -> filename:string -> Change.t -> t option (** Dump the patch diff in [dir] with the given prefix id. Output will be id.patch *) val dump : dir:string -> id:str...
null
https://raw.githubusercontent.com/squaresLab/footpatch/8b79c1964d89b833179aed7ed4fde0638a435782/infer/src/footpatch/patch.mli
ocaml
* A patch is a change bound to a file. Possible indentation is applied to the change. * Dump the patch diff in [dir] with the given prefix id. Output will be id.patch
type t val create: ?indent:Indent.t -> ?replace:bool -> filename:string -> Change.t -> t option val dump : dir:string -> id:string -> t -> unit val to_string : t -> string val pp : Format.formatter -> t -> unit val pps : unit -> t -> string
5b9e2cc91e899c4f59cb780721b352af27e96f4ae3cbfeebabc4af8d8cca99eb
argp/bap
batInterfaces.ml
* Interfaces - Common interfaces for data structures * Copyright ( C ) 2008 , LIFO , Universite d'Orleans * * This library is free software ; you can redistribute it and/or * modify it under the terms of the GNU Lesser General Public * License as published by the Free Software Foundation ; either ...
null
https://raw.githubusercontent.com/argp/bap/2f60a35e822200a1ec50eea3a947a322b45da363/batteries/src/batInterfaces.ml
ocaml
* Interfaces - Common interfaces for data structures * Copyright ( C ) 2008 , LIFO , Universite d'Orleans * * This library is free software ; you can redistribute it and/or * modify it under the terms of the GNU Lesser General Public * License as published by the Free Software Foundation ; either ...
74ea9f4518390a568df646286760d84dbec32303889870cdf59cde6bbaa186d0
dvingo/dv.fulcro-template
service.clj
(ns {{namespace}}.server.service (:require [clojure.pprint :refer [pprint]] [ring.util.request :as ring-req] [clojure.string :as string] [com.fulcrologic.fulcro.server.api-middleware :refer [handle-api-request]] [com.fulcrologic.guardrails.core :refer [>defn => | ?]] [dv.xtdb-ring-session-stor...
null
https://raw.githubusercontent.com/dvingo/dv.fulcro-template/69925a488bc4f1493f0a21cd003222212bb92e88/resources/clj/new/dv.fulcro_template/src/main/app/server/service.clj
clojure
needed for specs ================================================================================ Dynamically generated HTML. We do this so we can safely embed the CSRF token in a js var for use by the client, and to use hashed filename output from shadow. ==========================================================...
(ns {{namespace}}.server.service (:require [clojure.pprint :refer [pprint]] [ring.util.request :as ring-req] [clojure.string :as string] [com.fulcrologic.fulcro.server.api-middleware :refer [handle-api-request]] [com.fulcrologic.guardrails.core :refer [>defn => | ?]] [dv.xtdb-ring-session-stor...
3780f3eb8e9f4d194e302b4b41427e51870efb000c982dcf7be4d6f5a59ed126
uwplse/coq-plugin-lib
decompiler.mli
open Environ open Evd open Names open Constr open Stateutils Abstraction of Coq tactics supported by this decompiler . Serves as an intermediate representation that can be either transformed into a string or a sequence of actual tactics . Serves as an intermediate representation that can be either ...
null
https://raw.githubusercontent.com/uwplse/coq-plugin-lib/b249fc1954e2f1bc0b776e2d06e8ec1fc4d48ad9/src/coq/decompiler/decompiler.mli
ocaml
Proof that x = y if true, y = x if false, goal being transformed. Proof that y = x if true, x = y if false. env, induction arg, binding lists Paste the literal expression into the script. Represents a tactical proof script as a tree. Given a term and a list of tactics to try, decompile a term into an Ltac sc...
open Environ open Evd open Names open Constr open Stateutils Abstraction of Coq tactics supported by this decompiler . Serves as an intermediate representation that can be either transformed into a string or a sequence of actual tactics . Serves as an intermediate representation that can be either ...
e68ff240b6984f14cd140b0c974a7b7db830fe4521bbd0934c560100dec8704a
brendanhay/amazonka
GetRecommendations.hs
# LANGUAGE DeriveGeneric # # LANGUAGE DuplicateRecordFields # # LANGUAGE NamedFieldPuns # {-# LANGUAGE OverloadedStrings #-} # LANGUAGE RecordWildCards # {-# LANGUAGE StrictData #-} # LANGUAGE TypeFamilies # # LANGUAGE NoImplicitPrelude # # OPTIONS_GHC -fno - warn - unused - binds # # OPTIONS_GHC -fno - warn - unused -...
null
https://raw.githubusercontent.com/brendanhay/amazonka/09f52b75d2cfdff221b439280d3279d22690d6a6/lib/services/amazonka-wisdom/gen/Amazonka/Wisdom/GetRecommendations.hs
haskell
# LANGUAGE OverloadedStrings # # LANGUAGE StrictData # | Stability : auto-generated Retrieves recommendations for the specified session. To avoid retrieving the same recommendations in subsequent calls, use This API supports long-polling behavior with the @waitTimeSeconds@ parameter. Short poll is the default ...
# LANGUAGE DeriveGeneric # # LANGUAGE DuplicateRecordFields # # LANGUAGE NamedFieldPuns # # LANGUAGE RecordWildCards # # LANGUAGE TypeFamilies # # LANGUAGE NoImplicitPrelude # # OPTIONS_GHC -fno - warn - unused - binds # # OPTIONS_GHC -fno - warn - unused - imports # # OPTIONS_GHC -fno - warn - unused - matches # De...
b7846ff0aca258829ba93677acfb6d5a82ab7b3669f523c55cab70d0fd0f6696
returntocorp/semgrep
objet.mli
(*s: objet.mli *) TypeClass via objects . Cf also now interfaces.ml class virtual objet : object ('o) method invariant : unit -> unit (* method check: unit -> unit *) method of_string : string -> unit method to_string : unit -> string method debug : unit -> unit ugly ( but convenient ): thos...
null
https://raw.githubusercontent.com/returntocorp/semgrep/855abad9ada6ea5fd72d437fd69ff2e5fa42c1f1/libs/ograph/objet.mli
ocaml
s: objet.mli method check: unit -> unit e: objet.mli
TypeClass via objects . Cf also now interfaces.ml class virtual objet : object ('o) method invariant : unit -> unit method of_string : string -> unit method to_string : unit -> string method debug : unit -> unit ugly ( but convenient ): those methods allow to extend an interface without *...
20b3afa670ace8f3f30aabe0af949a8524d8519f185b68dcc7e16040697efdb3
termite-analyser/termite
subspace.mli
(** Operations on subspaces *) open Smt (** A subspace. *) type subspace (** [empty_subspace n] returns an empty subspace of Q^[n]. *) val empty_subspace : int -> subspace (** Returns the size of the subspace. *) val size : subspace -> int (** [is_empty subspace] returns [true] if the subspace is empty. *) val is...
null
https://raw.githubusercontent.com/termite-analyser/termite/285d92215a28fcce55614f6d04b44886f253a894/src/subspace.mli
ocaml
* Operations on subspaces * A subspace. * [empty_subspace n] returns an empty subspace of Q^[n]. * Returns the size of the subspace. * [is_empty subspace] returns [true] if the subspace is empty. * [add_to_subspace subspace v] adds the vector [v] to [subspace]. If [v] is already in [subspace], doesn't do anyth...
open Smt type subspace val empty_subspace : int -> subspace val size : subspace -> int val is_empty : subspace -> bool val add_to_subspace : subspace -> Q.t array -> unit val is_in : subspace -> Q.t array -> bool val avoid_space : subspace -> ZZ.znum ZZ.term array -> [> ZZ.zbool ] ZZ.term * { 2 Iteration } ...
0e1556348479b49722c13879d5913f1bef519f81621c4a5460a93896ee5f870a
sdiehl/llvm-tutorial-standalone
FFI.hs
{-# LANGUAGE OverloadedStrings #-} # LANGUAGE ForeignFunctionInterface # import JIT import Codegen import qualified LLVM.General.AST as AST import qualified LLVM.General.AST.Float as F import qualified LLVM.General.AST.Constant as C import Foreign.C.Types ; ModuleID = ' my cool jit ' declare void @myfunc(i64 )...
null
https://raw.githubusercontent.com/sdiehl/llvm-tutorial-standalone/8edcc083c8625c548ea9ce0ae76e5f5c1f13992c/src/FFI.hs
haskell
# LANGUAGE OverloadedStrings #
# LANGUAGE ForeignFunctionInterface # import JIT import Codegen import qualified LLVM.General.AST as AST import qualified LLVM.General.AST.Float as F import qualified LLVM.General.AST.Constant as C import Foreign.C.Types ; ModuleID = ' my cool jit ' declare void @myfunc(i64 ) define void ( ) { entry : ...
655327f560c2a7376bed69149ff94c16740d78e2c3ea7affff50959f603c08ba
Frama-C/Frama-C-snapshot
Splitter.mli
(**************************************************************************) (* *) This file is part of WP plug - in of Frama - C. (* *) Copyrigh...
null
https://raw.githubusercontent.com/Frama-C/Frama-C-snapshot/639a3647736bf8ac127d00ebe4c4c259f75f9b87/src/plugins/wp/Splitter.mli
ocaml
************************************************************************ alternatives) ...
This file is part of WP plug - in of Frama - C. Copyright ( C ) 2007 - 2019 CEA ( Commissariat a l'energie atomique et aux energies Lesser General Public License as published by the Free Software Foundation ,...
681d58a96bee0cc41cfaf7dce5c6b8443f593c97707b4d1e84b228c4379ad1ab
aws-beam/aws-erlang
aws_internetmonitor.erl
%% WARNING: DO NOT EDIT, AUTO-GENERATED CODE! See -beam/aws-codegen for more details . @doc Amazon CloudWatch Internet Monitor provides visibility into how %% internet issues impact the performance and availability between your applications hosted on Amazon Web Services and your end users , reducing the time i...
null
https://raw.githubusercontent.com/aws-beam/aws-erlang/7475363051ef714409e500ccd18fce26a7d65b0d/src/aws_internetmonitor.erl
erlang
WARNING: DO NOT EDIT, AUTO-GENERATED CODE! internet issues impact the performance and availability between your You can explore internet measurements for different time frames and at different geographic granularities, and quickly visualize the impact of issues, and then take action to improve your end users' exp...
See -beam/aws-codegen for more details . @doc Amazon CloudWatch Internet Monitor provides visibility into how applications hosted on Amazon Web Services and your end users , reducing the time it takes for you to diagnose these issues , from days to minutes . for example , by switching to other Amazon Web Ser...
d7b8c6b3bcbcccfffe810ca0a06f9529e2be55799e87d195e9b88718a5b38a3a
narkisr-deprecated/core
persmissions.clj
(ns re-core.integration.persistency.persmissions "System access permissions and envs" (:refer-clojure :exclude [type]) (:import clojure.lang.ExceptionInfo) (:require [flatland.useful.map :refer (dissoc-in*)] [re-core.security :refer (current-user)] [re-core.fixtures.data :refer (redis-ec2-spec redis...
null
https://raw.githubusercontent.com/narkisr-deprecated/core/85b4a768ef4b3a4eae86695bce36d270dd51dbae/test/re_core/integration/persistency/persmissions.clj
clojure
note that the assert-access precondition adds a current-user call
(ns re-core.integration.persistency.persmissions "System access permissions and envs" (:refer-clojure :exclude [type]) (:import clojure.lang.ExceptionInfo) (:require [flatland.useful.map :refer (dissoc-in*)] [re-core.security :refer (current-user)] [re-core.fixtures.data :refer (redis-ec2-spec redis...
6e740bbeefdf86755203f0a957124aa871c1ed0ffcfd8de1905b178a8013a0f6
krdlab/haskell-oidc-client
Client.hs
{-# OPTIONS_GHC -Wno-warnings-deprecations #-} {-# LANGUAGE OverloadedStrings #-} module Spec.Client where import Data.Aeson (Value (Null)) import Data.ByteString (ByteString) import Data.Text (unpack) import Data.Text.Encoding (decodeUtf8...
null
https://raw.githubusercontent.com/krdlab/haskell-oidc-client/b92736ba7d458b4d8571d378ad750b3e1ddaa7c4/test/Spec/Client.hs
haskell
# OPTIONS_GHC -Wno-warnings-deprecations # # LANGUAGE OverloadedStrings #
module Spec.Client where import Data.Aeson (Value (Null)) import Data.ByteString (ByteString) import Data.Text (unpack) import Data.Text.Encoding (decodeUtf8) import Network.HTTP.Client (newManager) import Network.H...
1eb05989987618d2789d4b3ebaacc148d8b3d2bf90989406dfddd5767aa3eaca
reborg/clojure-essential-reference
2.clj
(binding [*compile-path* "."] < 1 > ;; Compilation full path: examples/compile_file.clj ;; Compilation file name: compile_file.clj ;; examples.compile-file
null
https://raw.githubusercontent.com/reborg/clojure-essential-reference/9a3eb82024c8e5fbe17412af541c2cd30820c92e/DynamicVariablesintheStandardLibrary/*file*and*source-path*/2.clj
clojure
Compilation full path: examples/compile_file.clj Compilation file name: compile_file.clj examples.compile-file
(binding [*compile-path* "."] < 1 >
42abcfab43706c35f00057033c9cc1a2d7b6a4de4cd13e6b71843640b89498b9
mcorbin/tour-of-clojure
map.clj
(println (map inc [1 2 3 4]) "\n") (println (map #(+ % 10) [1 2 3 4]) "\n") (map (fn [v] (assoc v :foo "bar")) [{} {:foo "foo"} {:bar "baz"}])
null
https://raw.githubusercontent.com/mcorbin/tour-of-clojure/57f97b68ca1a8c96904bfb960f515217eeda24a6/resources/public/pages/code/map.clj
clojure
(println (map inc [1 2 3 4]) "\n") (println (map #(+ % 10) [1 2 3 4]) "\n") (map (fn [v] (assoc v :foo "bar")) [{} {:foo "foo"} {:bar "baz"}])
6c7c062faa67005ab4511e10240b07114a26e18bb6a9c7905c192fb480472ad8
dradtke/Lisp-Text-Editor
gdk.key-values.lisp
(in-package :gdk) (defcfun (keymap-get-default "gdk_keymap_get_default") (g-object keymap)) (export 'keymap-get-default) (defcfun (keymap-get-for-display "gdk_keymap_get_for_display") (g-object keymap) (display (g-object display))) (export 'keymap-get-for-display) (defcfun (keymap-lookup-key "gdk_keymap_lookup_k...
null
https://raw.githubusercontent.com/dradtke/Lisp-Text-Editor/b0947828eda82d7edd0df8ec2595e7491a633580/cl-gtk2/gdk/gdk.key-values.lisp
lisp
ignored:
(in-package :gdk) (defcfun (keymap-get-default "gdk_keymap_get_default") (g-object keymap)) (export 'keymap-get-default) (defcfun (keymap-get-for-display "gdk_keymap_get_for_display") (g-object keymap) (display (g-object display))) (export 'keymap-get-for-display) (defcfun (keymap-lookup-key "gdk_keymap_lookup_k...
92fa4cccad3fc54366cb7395157ba81a541664acd13f095d3dfb9d3b715d9b40
snoyberg/haskell-web-rosetta
yesod.hs
# LANGUAGE QuasiQuotes , TypeFamilies , MultiParamTypeClasses , TemplateHaskell # import Yesod import qualified Data.ByteString.Lazy as L import Data.Enumerator.List (consume) data App = App mkYesod "App" [$parseRoutes| / RootR PUT |] instance Yesod App where approot _ = "" putRootR = do bss <...
null
https://raw.githubusercontent.com/snoyberg/haskell-web-rosetta/43f8b736aed9a5bad375f5d1dc7ecc31979cb7c2/json-request/yesod.hs
haskell
# LANGUAGE QuasiQuotes , TypeFamilies , MultiParamTypeClasses , TemplateHaskell # import Yesod import qualified Data.ByteString.Lazy as L import Data.Enumerator.List (consume) data App = App mkYesod "App" [$parseRoutes| / RootR PUT |] instance Yesod App where approot _ = "" putRootR = do bss <...
3cc6644a20e10aff93f4547afd3bc1281cad99e2bb0adaf331c64b2dd215d0ba
dgiot/dgiot
dgiot_gps.erl
%%-------------------------------------------------------------------- Copyright ( c ) 2020 - 2021 DGIOT Technologies Co. , Ltd. All Rights Reserved . %% Licensed under the Apache License , Version 2.0 ( the " License " ) ; %% you may not use this file except in compliance with the License. %% You may obtain a copy...
null
https://raw.githubusercontent.com/dgiot/dgiot/ecf5d14518f24612b961ab01ce560d2d24374000/apps/dgiot_http/src/baidu/dgiot_gps.erl
erlang
-------------------------------------------------------------------- you may not use this file except in compliance with the License. You may obtain a copy of the License at -2.0 Unless required by applicable law or agreed to in writing, software WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express ...
Copyright ( c ) 2020 - 2021 DGIOT Technologies Co. , Ltd. All Rights Reserved . Licensed under the Apache License , Version 2.0 ( the " License " ) ; distributed under the License is distributed on an " AS IS " BASIS , -include_lib("dgiot/include/logger.hrl"). * Created by Wandergis on 2015/7/8 . * WGS : * ...
c8f08021cd7f506713ff7b993dc4de42b43ab151dfbc2551ba5426cf160a9f27
bos/configurator
Types.hs
-- | -- Module: Data.Configurator.Types Copyright : ( c ) 2011 MailRank , Inc. License : BSD3 Maintainer : < > -- Stability: experimental -- Portability: portable -- -- Types for working with configuration files. module Data.Configurator.Types ( AutoConfig(..) , Config , Nam...
null
https://raw.githubusercontent.com/bos/configurator/ff6d476562e9ff8b757832a81076d57e7a600fcf/Data/Configurator/Types.hs
haskell
| Module: Data.Configurator.Types Stability: experimental Portability: portable Types for working with configuration files. * Exceptions * Notification of configuration changes
Copyright : ( c ) 2011 MailRank , Inc. License : BSD3 Maintainer : < > module Data.Configurator.Types ( AutoConfig(..) , Config , Name , Value(..) , Configured, convert , Worth(..) , ConfigError(..) , KeyError(..) , Pattern , ChangeHandler ) where i...
35c88d744b2dad0a7b2a4f44ace7dc82e5d9ff295d38fda791e2bf7aa34ffe95
magnusjonsson/tidder-icfpc-2008
e-fifo.scm
#lang scheme (provide push! pop! make empty?) (define-struct fifo (first last) #:mutable #:transparent) (define (push! x q) (let ((new (mcons x '()))) (if (empty? q) (begin (set-fifo-first! q new) (set-fifo-last! q new)) (begin (set-mcdr! (fifo-last q) new) (set-fi...
null
https://raw.githubusercontent.com/magnusjonsson/tidder-icfpc-2008/84d68fd9ac358c38e7eff99117d9cdfa86c1864a/playground/scheme/stack/e-fifo.scm
scheme
#lang scheme (provide push! pop! make empty?) (define-struct fifo (first last) #:mutable #:transparent) (define (push! x q) (let ((new (mcons x '()))) (if (empty? q) (begin (set-fifo-first! q new) (set-fifo-last! q new)) (begin (set-mcdr! (fifo-last q) new) (set-fi...
101ae78168eae51e470588d97e6281412fdcd9f71fcb38fca4fd1aca03b95251
cardmagic/lucash
tty-consts.scm
;;; Constant definitions for tty control code (POSIX termios). Copyright ( c ) 1999 by . ;;; Special Control Characters ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; ;;; Indices into the c_cc[] character array. ;;; Name Subscript Enabled by ;;; ...
null
https://raw.githubusercontent.com/cardmagic/lucash/0452d410430d12140c14948f7f583624f819cdad/reference/scsh-0.6.6/scsh/cygwin32/tty-consts.scm
scheme
Constant definitions for tty control code (POSIX termios). Special Control Characters Indices into the c_cc[] character array. Name Subscript Enabled by ---- --------- ---------- POSIX ^u icanon ^c isig ^z isig !icanon ; Not exported !ic...
Copyright ( c ) 1999 by . ^d icanon icanon ^ ? icanon ^\ isig ^q ixon , ixoff ^s ixon , ixoff SVR4 & 4.3+BSD icanon 4.3+BSD (define num-ttychars 18) Magic " disable feature " tty character ixon SVR4 & 4.3+BSD SVR4 & 4.3+BSD onlcr : map nl to cr - n...
396895637760897a245180b690beecec76dac746bbd255e65a36b42039f0f4b6
robert-strandh/SICL
floating-point.lisp
(cl:in-package #:sicl-arithmetic) (defgeneric decode-float (float)) (defmethod decode-float ((float single-float)) (buoy:decode-single-float float)) (defmethod decode-float ((float double-float)) (buoy:decode-double-float float)) (defgeneric scale-float (float integer)) (defmethod scale-float ((float single-float) (i...
null
https://raw.githubusercontent.com/robert-strandh/SICL/517be7288c0d1815a95675435467d6686ab7c185/Code/Arithmetic/floating-point.lisp
lisp
(cl:in-package #:sicl-arithmetic) (defgeneric decode-float (float)) (defmethod decode-float ((float single-float)) (buoy:decode-single-float float)) (defmethod decode-float ((float double-float)) (buoy:decode-double-float float)) (defgeneric scale-float (float integer)) (defmethod scale-float ((float single-float) (i...
c2ea434c7c1464ca6be157aa87bac0a9adbcd0b84075843a6479cad9d47d2fd1
janestreet/hardcaml_xilinx_components
test_vhdl_to_hardcaml.ml
open! Import let test component = print_endline (Vhdl_to_hardcaml.vhdl_component_to_ocaml_module component) ;; let%expect_test "trivial component" = test { name = "component_name" ; generics = [] ; ports = [] }; [%expect {| module Component_name = struct module type P = sig ...
null
https://raw.githubusercontent.com/janestreet/hardcaml_xilinx_components/4d41ccfc0dc21242e48bc38ffa5a4b0a183f135a/xilinx_vhdl/test/test_vhdl_to_hardcaml.ml
ocaml
open! Import let test component = print_endline (Vhdl_to_hardcaml.vhdl_component_to_ocaml_module component) ;; let%expect_test "trivial component" = test { name = "component_name" ; generics = [] ; ports = [] }; [%expect {| module Component_name = struct module type P = sig ...
e596d3b70ad8b2d100766a5f61b2efbf876cd08c10f72c324c3a60d3f76344c8
jarmitage/jarmlib
NanoOSCMessages.hs
SAM - Nano OSC Sample Player Megakit :{ let note2Path = "/nanoosc/note2" note2Args = [("note", Nothing), -- 00 01 02 03 04 05 06 07 08 19 10 11 12 13 14 15 16 17 18 29 20 21 22 23 24 25 26 noteexp = pF "noteexp" pitch = pF "pitch...
null
https://raw.githubusercontent.com/jarmitage/jarmlib/853f6d18ab32630397be91ea89846d55e59e3d70/tidal/osc/targets/LiveCore/NanoOSCMessages.hs
haskell
00 00 00 00 00 00
SAM - Nano OSC Sample Player Megakit :{ let note2Path = "/nanoosc/note2" 01 02 03 04 05 06 07 08 19 10 11 12 13 14 15 16 17 18 29 20 21 22 23 24 25 26 noteexp = pF "noteexp" pitch = pF "pitch" high = pF "high" midgain = pF "midga...
9d939ea3fb90acc7cf8515cb17a770c89d666787f93a35c703409d2996d3afb0
jfacorro/klarna-loves-erlang-meetup-2020
bank_proper_statem.erl
-module(bank_proper_statem). -behaviour(proper_statem). -include("bank_proper.hrl"). -include_lib("proper/include/proper_common.hrl"). -include_lib("stdlib/include/assert.hrl"). -compile(export_all). -compile(nowarn_export_all). -include("bank_proper_statem.hrl"). %%================================================...
null
https://raw.githubusercontent.com/jfacorro/klarna-loves-erlang-meetup-2020/61795af0ac80ac7afa4a00a215342988e5aac45f/apps/bank_proper/src/bank_proper_statem.erl
erlang
============================================================================== The statem's property ============================================================================== ============================================================================== Setup =====================================================...
-module(bank_proper_statem). -behaviour(proper_statem). -include("bank_proper.hrl"). -include_lib("proper/include/proper_common.hrl"). -include_lib("stdlib/include/assert.hrl"). -compile(export_all). -compile(nowarn_export_all). -include("bank_proper_statem.hrl"). prop_main() -> setup(), ?FORALL( Cmds ...
3feba24410eaf85ba5d80c670e4b4f4c17f7ed0a1f0dbcea35caee0bec6f2dd0
richmit/mjrcalc
exp-ODEcircle.lisp
;; -*- Mode:Lisp; Syntax:ANSI-Common-LISP; Coding:us-ascii-unix; fill-column:158 -*- ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; ;;; ;; @file exp-ODEcircle.lisp @author < > ;; @brief Ex...
null
https://raw.githubusercontent.com/richmit/mjrcalc/96f66d030034754e7d3421688ff201f4f1db4833/exp-ODEcircle.lisp
lisp
-*- Mode:Lisp; Syntax:ANSI-Common-LISP; Coding:us-ascii-unix; fill-column:158 -*- @file exp-ODEcircle.lisp @brief Example of an ODE plot.@EOL @std Common Lisp Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are...
@author < > @parblock Copyright ( c ) 1999,2008,2012,2015 , < > All rights reserved . 1 . Redistributions of source code must retain the above copyright notice , this list of conditions , and the following disclaimer . 2 . Redistributions in binary form must reproduce the above copyright not...
c49e44b61662059a0c0ad3ba68d553a31588b1cd89469fe4526cd6853b6d65b7
YoshikuniJujo/test_haskell
makeEnumVkDependencyFlagBits.hs
# OPTIONS_GHC -Wall -fno - warn - tabs # module Main where import MakeEnum main :: IO () main = makeEnum'' "/usr/include/vulkan/vulkan_core.h" ["Data.Bits"] "DependencyFlagBits" "VkDependencyFlagBits" [("DependencyFlagsZero", Int 0)] ["Show", "Eq", "Storable", "Bits"] "type DependencyFlags = DependencyFlagBits"...
null
https://raw.githubusercontent.com/YoshikuniJujo/test_haskell/f5a039f30abf37655e296d86dac982f8449b6b4d/themes/gui/vulkan/try-my-vulkan/tools/makeEnumVkDependencyFlagBits.hs
haskell
# OPTIONS_GHC -Wall -fno - warn - tabs # module Main where import MakeEnum main :: IO () main = makeEnum'' "/usr/include/vulkan/vulkan_core.h" ["Data.Bits"] "DependencyFlagBits" "VkDependencyFlagBits" [("DependencyFlagsZero", Int 0)] ["Show", "Eq", "Storable", "Bits"] "type DependencyFlags = DependencyFlagBits"...
68044ad788139cd72ab83bb2a00eae570e50c98866ddced88105039de7f24785
oden-lang/oden
SourceFile.hs
module Oden.SourceFile where import Oden.QualifiedName data SourceFile = OdenSourceFile FilePath PackageName deriving (Show, Eq, Ord)
null
https://raw.githubusercontent.com/oden-lang/oden/10c99b59c8b77c4db51ade9a4d8f9573db7f4d14/src/Oden/SourceFile.hs
haskell
module Oden.SourceFile where import Oden.QualifiedName data SourceFile = OdenSourceFile FilePath PackageName deriving (Show, Eq, Ord)
fa953d79078d418a3449f1ce4dc76e5a26c589627e59e76798fee4ed310badf6
janestreet/memtrace_viewer
fragment_trie.ml
open! Core open Memtrace_viewer_common.For_testing module Location : Fragment_trie.Location with type t = char = struct include Char module Debug = Char let dummy = '_' end module Entry = struct include Int module Debug = Int end module Test_tree = struct type entry = int type location = char modul...
null
https://raw.githubusercontent.com/janestreet/memtrace_viewer/280d57dd520ed755497169e46b5fd0b11401d482/test/common/fragment_trie.ml
ocaml
Very naive construction for test purposes Assume each letter appears at most once per word (as we do for traces) Must be root Note that the ids in the fragment trie can change, so long as they do so consistently.
open! Core open Memtrace_viewer_common.For_testing module Location : Fragment_trie.Location with type t = char = struct include Char module Debug = Char let dummy = '_' end module Entry = struct include Int module Debug = Int end module Test_tree = struct type entry = int type location = char modul...
0773fa4f2e97303fd4185c14e6232a520dffe36cb4c96f0d43467a5fecac79c7
haslab/HAAP
CmdArgs.hs
HAAP : Haskell Automated Assessment Platform This module provides the @CmdArgs@ plugin ( < > ) for command - line argument support . HAAP: Haskell Automated Assessment Platform This module provides the @CmdArgs@ plugin (<>) for command-line argument support. -} # LANGUAGE DeriveDataTypeable , TypeOperators , ...
null
https://raw.githubusercontent.com/haslab/HAAP/5acf9efaf0e5f6cba1c2482e51bda703f405a86f/src/HAAP/CmdArgs.hs
haskell
HAAP : Haskell Automated Assessment Platform This module provides the @CmdArgs@ plugin ( < > ) for command - line argument support . HAAP: Haskell Automated Assessment Platform This module provides the @CmdArgs@ plugin (<>) for command-line argument support. -} # LANGUAGE DeriveDataTypeable , TypeOperators , ...
9b69d7601d63b9ff960eeaff8d03873d1262c089d201abd05d52a6894ab39b5b
namin/biohacker
ainter.lisp
;; -*- Mode: Lisp; -*- ATRE definitions and interface Last edited : 1/29/93 , Copyright ( c ) 1990 - 1993 , , Northwestern University , and , the Xerox Corporation . ;;; All rights reserved. ;;; See the file legal.txt for a paragraph stating scope of permission ;;; and disclaimer of warranty. The ab...
null
https://raw.githubusercontent.com/namin/biohacker/6b5da4c51c9caa6b5e1a68b046af171708d1af64/BPS/atms/ainter.lisp
lisp
-*- Mode: Lisp; -*- All rights reserved. See the file legal.txt for a paragraph stating scope of permission and disclaimer of warranty. The above copyright notice and that paragraph must be included in any separate copy of this file. Pretty name List of dbclasses Quick index into dbclasses Unique ID for asse...
ATRE definitions and interface Last edited : 1/29/93 , Copyright ( c ) 1990 - 1993 , , Northwestern University , and , the Xerox Corporation . (in-package :COMMON-LISP-USER) (defstruct (atre (:PREDICATE atre?) (:PRINT-FUNCTION print-atre)) Pointer to its ATMS State of the search , if any . ...
80cf51711ea5a1a8f7b05dc3dda06d1d10943f4cf9cbf4958a4979411470ad24
Kappa-Dev/KappaTools
purity.ml
* * purity.ml * openkappa * , projet Abstraction , INRIA Paris - Rocquencourt * * Creation : 01/02/2011 * Last modification : Time - stamp : < Aug 06 2016 > * * * Check that the input is written in pure Kappa * * Copyright 2010,2011 Institut National de Recherche en Informatique et * ...
null
https://raw.githubusercontent.com/Kappa-Dev/KappaTools/eef2337e8688018eda47ccc838aea809cae68de7/core/KaSa_rep/frontend/purity.ml
ocaml
* * purity.ml * openkappa * , projet Abstraction , INRIA Paris - Rocquencourt * * Creation : 01/02/2011 * Last modification : Time - stamp : < Aug 06 2016 > * * * Check that the input is written in pure Kappa * * Copyright 2010,2011 Institut National de Recherche en Informatique et * ...
5f3d94c9b38068b0526985258d321822501261d98081a267bb8e15d5e2da3fc0
gafiatulin/codewars
Faberge.hs
-- Fabergè Easter Eggs crush test module Faberge where heigth n m | n > m = heigth m m | otherwise = f 0 1 1 where f a b c | c > n = a | otherwise = f (a + d) d (c + 1) where d = b * (m - c + 1) `div` c
null
https://raw.githubusercontent.com/gafiatulin/codewars/535db608333e854be93ecfc165686a2162264fef/src/2%20kyu/Faberge.hs
haskell
Fabergè Easter Eggs crush test
module Faberge where heigth n m | n > m = heigth m m | otherwise = f 0 1 1 where f a b c | c > n = a | otherwise = f (a + d) d (c + 1) where d = b * (m - c + 1) `div` c
65761ff968277975e76c4ea5ad420b81fc9fe5b9ca5643ec98e8c4b0379d4c86
HaskellZhangSong/Introduction_to_Haskell_2ed_source
SF.hs
{-# LANGUAGE Arrows,DeriveFunctor #-} import Control.Arrow import Control.Category import Prelude hiding (id,(.)) import qualified Prelude as Prelude data SF a b = SF {runSF :: [a] -> [b]} instance Category SF where id = SF (Prelude.id) (.) (SF f) (SF g) = SF ((Prelude..) f g) instance Arrow SF where arr f...
null
https://raw.githubusercontent.com/HaskellZhangSong/Introduction_to_Haskell_2ed_source/140c50fdccfe608fe499ecf2d8a3732f531173f5/C23/SF.hs
haskell
# LANGUAGE Arrows,DeriveFunctor # f :: [b] -> [c] bd :: [(b,d)] res :: [(c,d)] f :: [(b,d)] -> [(c,d)] as :: [b] reset
import Control.Arrow import Control.Category import Prelude hiding (id,(.)) import qualified Prelude as Prelude data SF a b = SF {runSF :: [a] -> [b]} instance Category SF where id = SF (Prelude.id) (.) (SF f) (SF g) = SF ((Prelude..) f g) instance Arrow SF where arr f = SF (map f) first (SF f) = SF $ \...
d8a9c4483648204bbb961dfb83954b2c94a44e4b7940ec634d2afe39194d7ce0
janestreet/ppx_type_directed_value
type_directed_equal.mli
open Ppx_type_directed_value_runtime type 'a t = 'a -> 'a -> bool type 'a attribute = | CustomCmp of ('a -> 'a -> bool) | Ignore include Type_directed.S with type 'a T.t = 'a t and type 'a T.attribute = 'a attribute
null
https://raw.githubusercontent.com/janestreet/ppx_type_directed_value/f85693cc6d0ad8a9bc3bad55fed22a3d78e1fcaf/examples/type_directed_equal.mli
ocaml
open Ppx_type_directed_value_runtime type 'a t = 'a -> 'a -> bool type 'a attribute = | CustomCmp of ('a -> 'a -> bool) | Ignore include Type_directed.S with type 'a T.t = 'a t and type 'a T.attribute = 'a attribute
ea0a558fe48014731e09b4010cd4c39e02cfbe109fc9eb057785d4fb2d1f4d75
thattommyhall/offline-4clojure
p36.clj
;; Let it Be - Elementary ;; Can you bind x, y, and z so that these are all true? ;; tags - math:syntax ;; restricted - (ns offline-4clojure.p36 (:use clojure.test)) (def __ ;; your solution here ) (defn -main [] (are [soln] soln (= 10 (let __ (+ x y))) (= 4 (let __ (+ y z))) (= 1 (let __ z)) ))
null
https://raw.githubusercontent.com/thattommyhall/offline-4clojure/73e32fc6687816aea3c514767cef3916176589ab/src/offline_4clojure/p36.clj
clojure
Let it Be - Elementary Can you bind x, y, and z so that these are all true? tags - math:syntax restricted - your solution here
(ns offline-4clojure.p36 (:use clojure.test)) (def __ ) (defn -main [] (are [soln] soln (= 10 (let __ (+ x y))) (= 4 (let __ (+ y z))) (= 1 (let __ z)) ))
0be88188d63a5f6df0528ff7ae66947e84ebb6e146b54b6d602684a1d0e2f7b4
lisp-mirror/clpm
context.lisp
CLPM Contexts ;;;; This software is part of CLPM . See README.org for more information . See ;;;; LICENSE for license information. (in-package #:clpm-client) (defvar *default-context* nil "If non-NIL, the default context to use for most operations. Can either be a string (naming a global CLPM context) or a path...
null
https://raw.githubusercontent.com/lisp-mirror/clpm/ad9a704fcdd0df5ce30ead106706ab6cc5fb3e5b/clpm-client/context.lisp
lisp
LICENSE for license information.
CLPM Contexts This software is part of CLPM . See README.org for more information . See (in-package #:clpm-client) (defvar *default-context* nil "If non-NIL, the default context to use for most operations. Can either be a string (naming a global CLPM context) or a pathname to a clpmfile.") (defvar *active-cont...
fda673da6ec51fbbbc45e018515784f125fc8a1a132070e4e1020d6c5f050c48
shnarazk/mios
Writer.hs
{-# LANGUAGE Safe #-} -- | Write SAT data to DIMACS file module SAT.Mios.Util.DIMACS.Writer ( -- * Interface toFile , toDIMACSString , toString , toLatexString ) where import Data.List (intercalate, nub, sort) import System.IO -- | Write the DIMACS to file '...
null
https://raw.githubusercontent.com/shnarazk/mios/d032d761d73224f981a07ec2ea90936db6f495e8/MultiConflict/SAT/Mios/Util/DIMACS/Writer.hs
haskell
# LANGUAGE Safe # | Write SAT data to DIMACS file * Interface | Write the DIMACS to file 'f', using 'toDIMACSString' | Convert [Clause] to String, where Clause is [Int] >>> toDIMACSString [] "p cnf 0 0\n" | converts @[[Int]]@ to a String | converts @[[Int]]@ to a LaTeX expression
module SAT.Mios.Util.DIMACS.Writer ( toFile , toDIMACSString , toString , toLatexString ) where import Data.List (intercalate, nub, sort) import System.IO toFile :: FilePath -> [[Int]] -> IO () toFile f l = writeFile f $ toDIMACSString l > > > toDIMACSString [ [ -...
aba54552ecaf08f28188c890e1b0f2de2450e67c2e2051a54f9b42b51382947a
lambe-lang/nethra
location.ml
type t = int * int * int module Construct = struct (* Monoid neutral *) let initial = (0, 0, 0) (* Monoid combine *) let combine (position, line, column) (position', line', column') = (position + position', line + line', column + column') let create ~position ~line ~column = (position, line, column) en...
null
https://raw.githubusercontent.com/lambe-lang/nethra/bf68fa1d0e002cbb871ce2a21d99287e99405a8d/lib/nethra/syntax/source/location.ml
ocaml
Monoid neutral Monoid combine
type t = int * int * int module Construct = struct let initial = (0, 0, 0) let combine (position, line, column) (position', line', column') = (position + position', line + line', column + column') let create ~position ~line ~column = (position, line, column) end module Access = struct let position (p, _...
ab3bbf34409d27174db5932733f42303b5ab817a3d188facbcccd4243e140114
politrons/Dive_into_Haskell
MessageSystem.hs
module MessageSystem where import Network.Socket import System.IO import Control.Exception import Control.Concurrent import Control.Monad (when) import Control.Monad.Fix (fix) type MsgId = Int data Message = Message {msgId :: Int, msg ::String} messageSystem :: IO () messageSystem = do sock <- socket AF_INET Stream ...
null
https://raw.githubusercontent.com/politrons/Dive_into_Haskell/fd9dec14b87aecba0b3561385c1d75cf969546a4/src/programs/messageSystem/MessageSystem.hs
haskell
| We use [writeChan] function together with a channel and Message type to define a high order function [broadcast] which it will be used for the communication between clients. The function [createHandle] transform a [sock] into a [handle] to communicate directly with the owner of that socket | Function which pa...
module MessageSystem where import Network.Socket import System.IO import Control.Exception import Control.Concurrent import Control.Monad (when) import Control.Monad.Fix (fix) type MsgId = Int data Message = Message {msgId :: Int, msg ::String} messageSystem :: IO () messageSystem = do sock <- socket AF_INET Stream ...
b0e33e0e77068b4008c56035094a08478637727220d726bb9cb479d6f7836ca7
haskus/packages
Rotate.hs
# LANGUAGE DefaultSignatures # # LANGUAGE FlexibleContexts # -- | Bit rotations module Haskus.Binary.Bits.Rotate ( RotatableBits (..) ) where import Haskus.Binary.Bits.Finite import Haskus.Binary.Bits.Shift import Haskus.Binary.Bits.Bitwise import Haskus.Number.Word import Haskus.Number.Int import Haskus.Utils....
null
https://raw.githubusercontent.com/haskus/packages/40ea6101cea84e2c1466bc55cdb22bed92f642a2/haskus-binary/src/lib/Haskus/Binary/Bits/Rotate.hs
haskell
| Bit rotations | Types whose bits can be rotated | Rotate left if positive, right if negative | Checked left bit rotation | Checked right bit rotation | Unchecked rotate left if positive, right if negative | Unchecked left bit rotation | Unchecked right bit rotation
# LANGUAGE DefaultSignatures # # LANGUAGE FlexibleContexts # module Haskus.Binary.Bits.Rotate ( RotatableBits (..) ) where import Haskus.Binary.Bits.Finite import Haskus.Binary.Bits.Shift import Haskus.Binary.Bits.Bitwise import Haskus.Number.Word import Haskus.Number.Int import Haskus.Utils.Types class Rotata...
f19629b560d975a0fe3c8c77e2cc3966e6ee4ee67c0afb532d192e7a8a95fa1a
lpw25/ecaml
error.ml
(** Error reporting *) type t = Location.t * string * string let print (loc, error_kind, msg) = Print.message ~loc ~header:error_kind "%s" msg exception Error of t (** [error ~loc error_kind fmt] raises an [Error] of kind [error_kind] with a message [fmt] at a location [loc]. The [kfprintf] magic allows us to...
null
https://raw.githubusercontent.com/lpw25/ecaml/4588abb18436fb8a4983a353923ee667bf8c90a0/src/utils/error.ml
ocaml
* Error reporting * [error ~loc error_kind fmt] raises an [Error] of kind [error_kind] with a message [fmt] at a location [loc]. The [kfprintf] magic allows us to construct the [fmt] using a format string before raising the exception.
type t = Location.t * string * string let print (loc, error_kind, msg) = Print.message ~loc ~header:error_kind "%s" msg exception Error of t let error ?loc:(loc=Location.unknown) error_kind = let k _ = let msg = Format.flush_str_formatter () in raise (Error (loc, error_kind, msg)) in fun fmt -> Form...
7b4b437fd87300c91f9cd8c439faf5d2da679bfe7e9bb2cbaba6c1e9eb77743f
nasa/Common-Metadata-Repository
darwin.clj
(ns cmr.dev.env.manager.watcher.impl.darwin)
null
https://raw.githubusercontent.com/nasa/Common-Metadata-Repository/63001cf021d32d61030b1dcadd8b253e4a221662/other/cmr-exchange/dev-env-manager/src/cmr/dev/env/manager/watcher/impl/darwin.clj
clojure
(ns cmr.dev.env.manager.watcher.impl.darwin)
cc859b9b63936d3201e214a20ea55f2563f82174d243d8672bd955e771f0441e
awakesecurity/gRPC-haskell
Generated.hs
# LANGUAGE TypeFamilies # # LANGUAGE DataKinds # {-# LANGUAGE RankNTypes #-} {-# LANGUAGE OverloadedStrings #-} module Network.GRPC.HighLevel.Generated ( -- * Types MetadataMap(..) , MethodName(..) , GRPCMethodType(..) , GRPCImpl(..) , MkHandler , Host(..) , Port(..) , StatusDetails(..) , StatusCode(..) , GRPCIOE...
null
https://raw.githubusercontent.com/awakesecurity/gRPC-haskell/112777023f475ddd752c954056e679fbca0baa44/src/Network/GRPC/HighLevel/Generated.hs
haskell
# LANGUAGE RankNTypes # # LANGUAGE OverloadedStrings # * Types * Server * Server Auth * Client | Used at the kind level as a parameter to service definitions generated by the grpc compiler, with the effect of having the field types reduce to the appropriate types for the method types. can define a type to...
# LANGUAGE TypeFamilies # # LANGUAGE DataKinds # module Network.GRPC.HighLevel.Generated ( MetadataMap(..) , MethodName(..) , GRPCMethodType(..) , GRPCImpl(..) , MkHandler , Host(..) , Port(..) , StatusDetails(..) , StatusCode(..) , GRPCIOError(..) , ServiceOptions(..) , defaultServiceOptions , ServerCall(..) , se...
d6a4d1ef4ab0637b9bfbc13f6d7670638aa6a093dab3606c3a214b1dd55d123e
rtrusso/scp
r5rs-syntax.scm
(define-syntax quasiquote (syntax-rules (unquote unquote-splicing) ((_ (unquote <obj>)) <obj>) ((_ ((unquote-splicing <obj1>) <obj2> ...)) (append <obj1> (quasiquote (<obj2> ...)))) ((_ (<obj1> <obj2> ...)) (cons (quasiquote <obj1>) (quasiquote (<obj2> ...))...
null
https://raw.githubusercontent.com/rtrusso/scp/2051e76df14bd36aef81aba519ffafa62b260f5c/src/rtl/r5rs-syntax.scm
scheme
((letrec ((tag (lambda (name ...) tag) val ...)))) ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; for recognition by the optimizer or code generator. Instead, letrec is considered a special form. (define-syntax letre...
(define-syntax quasiquote (syntax-rules (unquote unquote-splicing) ((_ (unquote <obj>)) <obj>) ((_ ((unquote-splicing <obj1>) <obj2> ...)) (append <obj1> (quasiquote (<obj2> ...)))) ((_ (<obj1> <obj2> ...)) (cons (quasiquote <obj1>) (quasiquote (<obj2> ...))...
23369c88fda1efb654298d006e37274690e9a2d121e4e18ba7a9f7f01fbe2769
unnohideyuki/bunny
sample176.hs
main = print x where x = 13
null
https://raw.githubusercontent.com/unnohideyuki/bunny/501856ff48f14b252b674585f25a2bf3801cb185/compiler/test/samples/sample176.hs
haskell
main = print x where x = 13
62c4a785339d90855a1e5c93adf090ad3cf6e8c96f5079ad5936369b33884a29
barrel-db/barrel
barrel_memory.erl
-module(barrel_memory). -export([get_total_memory/0, get_vm_limit/0]). -define(ONE_MB, 1048576). -spec get_total_memory() -> (non_neg_integer() | 'unknown'). -spec get_vm_limit() -> non_neg_integer(). get_total_memory() -> try get_total_memory(os:type()) catch _:Error -> _ = lager:warn...
null
https://raw.githubusercontent.com/barrel-db/barrel/1695ca4cfe821808526f9ecb2e019bc1b8eff48e/src/util/barrel_memory.erl
erlang
According to -us/library/aa366778(VS.85).aspx in big trouble anyway. -64#Virtual_address_space_details ---------------------------------------------------------------------------- Internal Helpers ---------------------------------------------------------------------------- get_total_memory(OS) -> Total A line look...
-module(barrel_memory). -export([get_total_memory/0, get_vm_limit/0]). -define(ONE_MB, 1048576). -spec get_total_memory() -> (non_neg_integer() | 'unknown'). -spec get_vm_limit() -> non_neg_integer(). get_total_memory() -> try get_total_memory(os:type()) catch _:Error -> _ = lager:warn...
21364bc09cc3d7129ab9483003cf94a5a25dc9d13c9a889c532e2f044dc7d6b6
sjl/advent
day-02.lisp
(advent:defpackage* :advent/2018/02) (in-package :advent/2018/02) (define-problem (2018 2) (data read-lines) (8296 "pazvmqbftrbeosiecxlghkwud") (values (let* ((freqs (mapcar #'frequencies data)) (counts (mapcar #'alexandria:hash-table-values freqs))) (* (count 2 counts :test #'member) ...
null
https://raw.githubusercontent.com/sjl/advent/dc3debda9bd1a0570a6ab06919b1af7b285413dc/src/2018/days/day-02.lisp
lisp
just brute force it
(advent:defpackage* :advent/2018/02) (in-package :advent/2018/02) (define-problem (2018 2) (data read-lines) (8296 "pazvmqbftrbeosiecxlghkwud") (values (let* ((freqs (mapcar #'frequencies data)) (counts (mapcar #'alexandria:hash-table-values freqs))) (* (count 2 counts :test #'member) ...
4e352283d28cd43c4e2fda54f300eff6926d005db6c191a6df4aa60c53c50efe
prg-titech/Kani-CUDA
out.rkt
#lang rosette (require "../Emulator/lang.rkt") (delete-directory/files "profiles" #:must-exist? #f) (make-directory* "profiles") (func void __global__diffusion_kernel ((float in) (float out) (int nx) (int ny) (int nz) (float ce) (float cw) (float cn) (float cs) (float ct) (float cb) (float cc)...
null
https://raw.githubusercontent.com/prg-titech/Kani-CUDA/e97c4bede43a5fc4031a7d2cfc32d71b01ac26c4/Synthesizer/out.rkt
racket
#lang rosette (require "../Emulator/lang.rkt") (delete-directory/files "profiles" #:must-exist? #f) (make-directory* "profiles") (func void __global__diffusion_kernel ((float in) (float out) (int nx) (int ny) (int nz) (float ce) (float cw) (float cn) (float cs) (float ct) (float cb) (float cc)...
00f9c93da332255b368ae425f923013528fd02b066960ce62733ac3fde7c1934
spechub/Hets
AnaLib.hs
| Module : ./Driver / AnaLib.hs Description : wrapper for static analysis of DOL Copyright : ( c ) , Uni Bremen 2002 - 2006 License : GPLv2 or higher , see LICENSE.txt Maintainer : Stability : provisional Portability : non - portable(Logic ) wrapper for static anal...
null
https://raw.githubusercontent.com/spechub/Hets/98f81719637d37092aa29178822f662e99e69e36/Driver/AnaLib.hs
haskell
| lookup an env or read and analyze a file | read a file and extended the current library environment
| Module : ./Driver / AnaLib.hs Description : wrapper for static analysis of DOL Copyright : ( c ) , Uni Bremen 2002 - 2006 License : GPLv2 or higher , see LICENSE.txt Maintainer : Stability : provisional Portability : non - portable(Logic ) wrapper for static anal...
7dedb3927835d5cf21fcf850139d0d595d84514175278e777f9993388177ad52
jchavarri/rebind
ast_helper.ml
(***********************************************************************) (* *) (* OCaml *) (* *) ...
null
https://raw.githubusercontent.com/jchavarri/rebind/ccfa1725ff5b16574daf4d0044c49dbf719aa105/vendor/ocaml/parsing/ast_helper.ml
ocaml
********************************************************************* OCaml ...
, LexiFi Copyright 2012 Institut National de Recherche en Informatique et en Automatique . All rights reserved . This file is distributed under the terms of the Q Public License version 1.0 . * Helpers to produce Parsetree fragments...
53f04066b7ec6e44d9ce5d5f494373e7cb6d92bd1c5515d279c7d652721bfcb5
craigfe/sink
cmd.mli
val mkdir_p : string -> unit val print_to_file : string -> (Format.formatter -> unit) -> unit val sequence_commands : string list -> (unit, [ `Msg of string ]) result
null
https://raw.githubusercontent.com/craigfe/sink/c5431edfa1b06f1a09845a481c4afcb3e92f0667/src/sink-unix/cmd.mli
ocaml
val mkdir_p : string -> unit val print_to_file : string -> (Format.formatter -> unit) -> unit val sequence_commands : string list -> (unit, [ `Msg of string ]) result
e729c535ea9e1d2ebd751d462d66318e2852e02b97bad0a1d0da6cc8b3c211f7
grin-compiler/ghc-wpc-sample-programs
Lua.hs
| Module : Text . Pandoc . Filter . Lua Copyright : Copyright ( C ) 2006 - 2020 License : GNU GPL , version 2 or above Maintainer : < jgm@berkeley@edu > Stability : alpha Portability : portable Apply Lua filters to modify a pandoc documents programmatically . ...
null
https://raw.githubusercontent.com/grin-compiler/ghc-wpc-sample-programs/0e3a9b8b7cc3fa0da7c77fb7588dd4830fb087f7/pandoc-11df2a3c0f2b1b8e351ad8caaa7cdf583e1b3b2e/src/Text/Pandoc/Filter/Lua.hs
haskell
| Module : Text . Pandoc . Filter . Lua Copyright : Copyright ( C ) 2006 - 2020 License : GNU GPL , version 2 or above Maintainer : < jgm@berkeley@edu > Stability : alpha Portability : portable Apply Lua filters to modify a pandoc documents programmatically . ...
9b64eca829b6902ddb45b771412bc08fe09e85fa331cea32b510314d3c7a1db3
spechub/Hets
Parse_AS.hs
{-# LANGUAGE RankNTypes #-} | Module : ./TopHybrid / Parse_AS.hs License : GPLv2 or higher , see LICENSE.txt Maintainer : Stability : provisional Portability : portable Description : for an hybridized arbitrary logic Module : ./TopHybrid/Parse_AS.hs License :...
null
https://raw.githubusercontent.com/spechub/Hets/af7b628a75aab0d510b8ae7f067a5c9bc48d0f9e/TopHybrid/Parse_AS.hs
haskell
# LANGUAGE RankNTypes # the top parser; parses an entire specification Parses the specification after knowing the underlying logic Calls the underlying logic parser, only if exists. Otherwise will throw out an error Parses the declaration of nominals and modalities ------------
| Module : ./TopHybrid / Parse_AS.hs License : GPLv2 or higher , see LICENSE.txt Maintainer : Stability : provisional Portability : portable Description : for an hybridized arbitrary logic Module : ./TopHybrid/Parse_AS.hs License : GPLv2 or higher, see LICEN...
593a203e26d0566468e6e2b3a3ef1b8cb5879696586ae91b05ee19727a118524
EveryTian/Haskell-Codewars
dont-give-me-five.hs
-give-me-five module Kata where dontGiveMeFive :: Int -> Int -> Int dontGiveMeFive start end = let boolList = map (\ x -> '5' `elem` show x) [start..end] in foldl (\ num x -> if not x then num + 1 else num) 0 boolList
null
https://raw.githubusercontent.com/EveryTian/Haskell-Codewars/dc48d95c676ce1a59f697d07672acb6d4722893b/7kyu/dont-give-me-five.hs
haskell
-give-me-five module Kata where dontGiveMeFive :: Int -> Int -> Int dontGiveMeFive start end = let boolList = map (\ x -> '5' `elem` show x) [start..end] in foldl (\ num x -> if not x then num + 1 else num) 0 boolList
84c9f563ddc90b79ce87564fa262084e154106053fbbb5100a27956d241f0ec4
sgbj/MaximaSharp
dqelg.lisp
;;; Compiled by f2cl version: ( " f2cl1.l , v 46c1f6a93b0d 2012/05/03 04:40:28 toy $ " " f2cl2.l , v 96616d88fb7e 2008/02/22 22:19:34 rtoy $ " " f2cl3.l , v 96616d88fb7e 2008/02/22 22:19:34 rtoy $ " " f2cl4.l , v 96616d88fb7e 2008/02/22 22:19:34 rtoy $ " ;;; "f2cl5.l,v 46c1f6a93b0d 2012/05/03 04:40:28 toy $...
null
https://raw.githubusercontent.com/sgbj/MaximaSharp/75067d7e045b9ed50883b5eb09803b4c8f391059/Test/bin/Debug/Maxima-5.30.0/share/maxima/5.30.0/src/numerical/slatec/dqelg.lisp
lisp
Compiled by f2cl version: "f2cl5.l,v 46c1f6a93b0d 2012/05/03 04:40:28 toy $" Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t) (:coerce-assigns :as-needed) (:array-type ':array) (:array-slicing t) (:declare-common nil) (:float-format double-float))
( " f2cl1.l , v 46c1f6a93b0d 2012/05/03 04:40:28 toy $ " " f2cl2.l , v 96616d88fb7e 2008/02/22 22:19:34 rtoy $ " " f2cl3.l , v 96616d88fb7e 2008/02/22 22:19:34 rtoy $ " " f2cl4.l , v 96616d88fb7e 2008/02/22 22:19:34 rtoy $ " " f2cl6.l , v 1d5cbacbb977 2008/08/24 00:56:27 rtoy $ " " macros.l , v fceac53...
2dc55735683d1a30b685141b9e079157cab074467e668e1526ed2c4b306de540
tenpureto/tenpureto
MergeOptimizerTest.hs
module Tenpureto.MergeOptimizerTest where import Test.Tasty import Test.Tasty.HUnit import Data.Functor.Identity import Data.Text ( Text ) import Tenpureto.Graph import Tenpureto.MergeOptimizer import qualified Tenpureto.OrderedMap ...
null
https://raw.githubusercontent.com/tenpureto/tenpureto/886df860200e1a6f44ce07c24a5e7597009f71ef/test/Tenpureto/MergeOptimizerTest.hs
haskell
module Tenpureto.MergeOptimizerTest where import Test.Tasty import Test.Tasty.HUnit import Data.Functor.Identity import Data.Text ( Text ) import Tenpureto.Graph import Tenpureto.MergeOptimizer import qualified Tenpureto.OrderedMap ...
2e7afb5d9adfbd7203cc519dcfe7b24419471cc0f9d9f15e3b0ec93a8f28e2ad
ghc/testsuite
tcfail177.hs
module ShouldFail where See Trac # 1176 -- This is really a pretty-printer test, not a typechecker test -- The more infix ops we have, the worse fsep works -- Currently the error message looks ok, however allTests :: Bool allTests = foo [a ~?= b ,"Three" ~?= "3" ,"Four" ~?= "4" ...
null
https://raw.githubusercontent.com/ghc/testsuite/998a816ae89c4fd573f4abd7c6abb346cf7ee9af/tests/typecheck/should_fail/tcfail177.hs
haskell
This is really a pretty-printer test, not a typechecker test The more infix ops we have, the worse fsep works Currently the error message looks ok, however
module ShouldFail where See Trac # 1176 allTests :: Bool allTests = foo [a ~?= b ,"Three" ~?= "3" ,"Four" ~?= "4" ,"Five" ~?= "5" ,"Five" ~?= "5" ,"Five" ~?= "5" ,"Five" ~?= "5" ,"Five" ~?= "5" ,"Five" ~?= "5" ...
18d0ef3dce83f366d6f963e97c1c321cb152da4581dd3f66b85cc11e534a847c
Deducteam/Dedukti
rule.mli
open Basic open Term (** Rewrite rules *) (** {2 Patterns} *) (** Basic representation of pattern *) type pattern = | Var of loc * ident * int * pattern list (** Applied DB variable *) | Pattern of loc * name * pattern list (** Applied constant *) | Lambda of loc * ident * pattern (** Lambda abstraction ...
null
https://raw.githubusercontent.com/Deducteam/Dedukti/af7dfba10b4858354524ed798b8b58dd2cf2b923/kernel/rule.mli
ocaml
* Rewrite rules * {2 Patterns} * Basic representation of pattern * Applied DB variable * Applied constant * Lambda abstraction * Bracket of a term * Applied Miller variable * Lambda abstraction * Applied constant * Locally bound variable * [constr] is the type of brackets (aka "dot") patte...
open Basic open Term type pattern = val get_loc_pat : pattern -> loc val pattern_to_term : pattern -> term * Efficient representation for well - formed linear pattern type wf_pattern = | LJoker | LACSet of name * wf_pattern list * { 2 Brackets } type constr = int * term val pp_constr : constr printer * {...
b3d8ad5b4cdb3924ead369a551cccaebc0ddb386a1de49e1ea14e5e8343ecfcd
cunger/pythia
Core_Anaphora.clj
(ns core.definitions.Core_Anaphora (:require [core.data.LambdaRDF :refer :all]) (:import [core.data.LambdaRDF Condition Sel And Triple])) ;; Anaphora (def I (Sel. [(Condition. :referent :speaker) (Condition. :number :singular)])) (def We (Sel. [(Condition. :referent :speaker) (Condition. :number :plural...
null
https://raw.githubusercontent.com/cunger/pythia/f58e35395968d4c46aef495fd363c26b1102003c/src/core/definitions/Core_Anaphora.clj
clojure
Anaphora (def this (sel ...) (def that (sel ...)
(ns core.definitions.Core_Anaphora (:require [core.data.LambdaRDF :refer :all]) (:import [core.data.LambdaRDF Condition Sel And Triple])) (def I (Sel. [(Condition. :referent :speaker) (Condition. :number :singular)])) (def We (Sel. [(Condition. :referent :speaker) (Condition. :number :plural)])) (def Yo...
a29da81a814a85f95f99b9406bf9ec1acc63cc0f9b7e22170ebb2674dd1650d9
jellelicht/guix
cpan.scm
;;; GNU Guix --- Functional package management for GNU Copyright © 2015 < > ;;; ;;; This file is part of GNU Guix. ;;; GNU is free software ; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation ; either version 3 of the Lice...
null
https://raw.githubusercontent.com/jellelicht/guix/83cfc9414fca3ab57c949e18c1ceb375a179b59c/tests/cpan.scm
scheme
GNU Guix --- Functional package management for GNU This file is part of GNU Guix. you can redistribute it and/or modify it either version 3 of the License , or ( at your option) any later version. GNU Guix is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied wa...
Copyright © 2015 < > under the terms of the GNU General Public License as published by You should have received a copy of the GNU General Public License along with GNU . If not , see < / > . (define-module (test-cpan) #:use-module (guix import cpan) #:use-module (guix base32) #:use-module (guix has...
06a246aeeb90df1938aafc0e40b3fa71135586b62c53c1b0fa234e7eea0ce13b
jrclogic/SMCDEL
DoorMat.hs
module SMCDEL.Examples.DoorMat where import SMCDEL.Explicit.S5 as Exp hiding (announce) import SMCDEL.Language import SMCDEL.Symbolic.S5 hiding (announce) import SMCDEL.Translations.S5 import SMCDEL.Other.Planning explain :: Prp -> String explain (P 1) = "key-under-mat" explain (P 2) = "bob-has-key" explain (P k) = "...
null
https://raw.githubusercontent.com/jrclogic/SMCDEL/10bd5ba2f1f3cc85e4b0f23d5eddbb26f05df5bf/src/SMCDEL/Examples/DoorMat.hs
haskell
actually, the key is under the mat
module SMCDEL.Examples.DoorMat where import SMCDEL.Explicit.S5 as Exp hiding (announce) import SMCDEL.Language import SMCDEL.Symbolic.S5 hiding (announce) import SMCDEL.Translations.S5 import SMCDEL.Other.Planning explain :: Prp -> String explain (P 1) = "key-under-mat" explain (P 2) = "bob-has-key" explain (P k) = "...
2cb3624c6aa8fa3b824a3d8aabb577f6904d790354df7ae67c165df8715fce52
titola/incudine
spinlock.lisp
Copyright ( c ) 2013 - 2021 ;;; ;;; This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation ; either version 2 of the License , or ;;; (at your option) any later version. ;;; ;;; This program is distri...
null
https://raw.githubusercontent.com/titola/incudine/6e932a4134cbf64140145d1e3506637048c978c3/src/spinlock.lisp
lisp
This program is free software; you can redistribute it and/or modify either version 2 of the License , or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR...
Copyright ( c ) 2013 - 2021 it under the terms of the GNU General Public License as published by You should have received a copy of the GNU General Public License Foundation , Inc. , 51 Franklin St , Fifth Floor , Boston , MA 02110 - 1301 USA (in-package :incudine.util) (defstruct (spinlock (:constructo...
25de6101c4f8019040d03d3ca7718d58fac55c7e6bed27f1e80f86d77998490f
tud-fop/vanda-haskell
LimitedQueue.hs
----------------------------------------------------------------------------- -- | -- Module : Data.LimitedQueue Copyright : ( c ) 2017 -- License : BSD-style -- -- Maintainer : -- Stability : unknown -- Portability : portable -- -- This module implements a search queue that: -- -- * is limit...
null
https://raw.githubusercontent.com/tud-fop/vanda-haskell/3214966361b6dbf178155950c94423eee7f9453e/library/Data/LimitedQueue.hs
haskell
--------------------------------------------------------------------------- | Module : Data.LimitedQueue License : BSD-style Maintainer : Stability : unknown Portability : portable This module implements a search queue that: * is limited to a fixed number of elements that it contains at onc...
Copyright : ( c ) 2017 It is implemented using the ' findMin ' and ' ' API of " Data . Map . Strict " and ordered minimum first . module Data.LimitedQueue Queue , empty , fromList , enq , enqList , deq , null ) where import qualified Data.Map.Strict as M import qualif...
ef5fbaf9a2b7f70ad9202bdc7f7129fb96d2a20ac8fd5e1636ad81953b135247
haskell-opengl/OpenGLRaw
HalfFloat.hs
# LANGUAGE PatternSynonyms # -------------------------------------------------------------------------------- -- | -- Module : Graphics.GL.NV.HalfFloat Copyright : ( c ) 2019 -- License : BSD3 -- Maintainer : < > -- Stability : stable -- Portability : portable -- -----------------------...
null
https://raw.githubusercontent.com/haskell-opengl/OpenGLRaw/57e50c9d28dfa62d6a87ae9b561af28f64ce32a0/src/Graphics/GL/NV/HalfFloat.hs
haskell
------------------------------------------------------------------------------ | Module : Graphics.GL.NV.HalfFloat License : BSD3 Stability : stable Portability : portable ------------------------------------------------------------------------------ * Extension Support * Enums * Functions
# LANGUAGE PatternSynonyms # Copyright : ( c ) 2019 Maintainer : < > module Graphics.GL.NV.HalfFloat ( glGetNVHalfFloat, gl_NV_half_float, pattern GL_HALF_FLOAT_NV, glColor3hNV, glColor3hvNV, glColor4hNV, glColor4hvNV, glFogCoordhNV, glFogCoordhvNV, glMultiTexCoord1hNV, glMultiT...
fd2ffb1f7d4c5e1227d42d093a7445d3c0ca2db6b566e7b81d0fdbaa66b55e80
RedPRL/cooltt
Semantics.mli
open Monads open CodeUnit module S := Syntax module D := Domain val eval : S.t -> D.con evaluate val eval_cof : S.t -> D.cof evaluate val eval_tp : S.tp -> D.tp evaluate val eval_sign : S.sign -> D.sign evaluate type 'a whnf = [`Done | `Reduce of 'a] val whnf_con : D.con -> D.con whnf compute val whnf_cut : D.cut -...
null
https://raw.githubusercontent.com/RedPRL/cooltt/293df344bc769ac3ba5065956d1f7736136d2535/src/core/Semantics.mli
ocaml
open Monads open CodeUnit module S := Syntax module D := Domain val eval : S.t -> D.con evaluate val eval_cof : S.t -> D.cof evaluate val eval_tp : S.tp -> D.tp evaluate val eval_sign : S.sign -> D.sign evaluate type 'a whnf = [`Done | `Reduce of 'a] val whnf_con : D.con -> D.con whnf compute val whnf_cut : D.cut -...
35db2586fbedc68ec67f24fa17ee74f6b4db292cd55badd5bf4bc42d1196f466
travisbrady/flajolet
destats.ml
(* * A simple utility to compute some basic descriptive from a column * of numbers read from stdin * The output is similar in spirit to pandas .describe method * and R's summary * *) open Core.Std let printf = Printf.printf let show_result hist _count = let _min = Histogram.min hist in let mean = Histogr...
null
https://raw.githubusercontent.com/travisbrady/flajolet/a6c530bf1dd73b9fa8b7185d84a5e20458a3d8af/examples/destats.ml
ocaml
* A simple utility to compute some basic descriptive from a column * of numbers read from stdin * The output is similar in spirit to pandas .describe method * and R's summary *
open Core.Std let printf = Printf.printf let show_result hist _count = let _min = Histogram.min hist in let mean = Histogram.mean hist in let std = Histogram.std hist in let first_quartile = Histogram.quantile hist 0.25 in let median = Histogram.quantile hist 0.5 in let third_quartile = Histogr...
3009b3a67fca218a7a0820b15d2b3aafefba210e2acd305fc049ac39bc55530e
Metaxal/MrEd-Designer
widget.rkt
#lang racket (require "../../mred-plugin.rkt" "../../default-values.rkt" "preview.rkt" "../project/preview.rkt" ; needed for plugin% class... ; ???? WARNING: make-plugin?? racket/gui/base) (make-plugin [type 'frame] [tooltip "Frame"] [button-group "Containers"] [widget-class p...
null
https://raw.githubusercontent.com/Metaxal/MrEd-Designer/220833b738a1d46fbe309ea124ef61b825e42e68/mred-designer/widgets/frame/widget.rkt
racket
needed for plugin% class... ; ???? WARNING: make-plugin?? for code generation. By default the same as widget-class can only instantiate under a frame% or a project% necessary properties widget properties [parent #f] ; NO! do NOT use the parent property! optional
#lang racket (require "../../mred-plugin.rkt" "../../default-values.rkt" "preview.rkt" racket/gui/base) (make-plugin [type 'frame] [tooltip "Frame"] [button-group "Containers"] [widget-class preview-frame%] [options '(id)] [no-code '(show-at-init)] [post-code (λ(mid)(if (send mid get...
319d0aea54f16c699c548452361b29ea306bfefe6515d97e74919fbb381baa82
alexbecker/blogdown
Text.hs
module Parsing.Text (plaintext) where import Data.List.Utils (endswith) import Data.Maybe import Text.Parsec import Parsing.State import Parsing.Utils specials = "*`<>[]|\\" specialStrings = ["^[", "!["] firstCharSpecials = " \t#~+\n" ++ specials Parse a single non - special character , allowing for escaping and ...
null
https://raw.githubusercontent.com/alexbecker/blogdown/7ebbb238e393c3f5e93822d6db2587d0150c80e7/src/Parsing/Text.hs
haskell
continuation rules for special characters at the start of a line. Note that this does not consume as many non-special characters as possible, for ease of implementation. Don't succeed without consuming any input.
module Parsing.Text (plaintext) where import Data.List.Utils (endswith) import Data.Maybe import Text.Parsec import Parsing.State import Parsing.Utils specials = "*`<>[]|\\" specialStrings = ["^[", "!["] firstCharSpecials = " \t#~+\n" ++ specials Parse a single non - special character , allowing for escaping and ...
70b20c06952de624c3d266ec55068be739152d9af12c08259f2fb396ecce01fd
shirok/Gauche
fileutil.scm
;;; ;;; file related utility functions. to be autoloaded. ;;; Copyright ( c ) 2000 - 2022 < > ;;; ;;; Redistribution and use in source and binary forms, with or without ;;; modification, are permitted provided that the following conditions ;;; are met: ;;; ;;; 1. Redistributions of source code must ...
null
https://raw.githubusercontent.com/shirok/Gauche/b773899dbe0b2955e1c4f1daa066da874070c1e4/lib/gauche/fileutil.scm
scheme
file related utility functions. to be autoloaded. Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 1. Redistributions of source code must retain the above copyright notice, this list of conditions and t...
Copyright ( c ) 2000 - 2022 < > " AS IS " AND ANY EXPRESS OR IMPLIED WARRANTIES , INCLUDING , BUT NOT SPECIAL , EXEMPLARY , OR CONSEQUENTIAL DAMAGES ( INCLUDING , BUT NOT LIMITED LIABILITY , WHETHER IN CONTRACT , STRICT LIABILITY , OR TORT ( INCLUDING #!no-fold-case (define-module gauche.fileut...
c76e4a6cf2d3a106c69db35d9f933881040b7dcc6919f02da3512abc1686df6e
glv/snergly
project.clj
(defproject snergly "0.1.0-SNAPSHOT" :description "Maze algorithms in Clojure (from Jamis Buck's /Mazes for Programmers/ book)" :url "" :license {:name "Eclipse Public License" :url "-v10.html"} :main ^:skip-aot snergly.core :dependencies [[org.clojure/clojure "1.10.3"] [org.cloju...
null
https://raw.githubusercontent.com/glv/snergly/2f09860b3b3f8d2a58d8a2b2b63184c4a7240f05/project.clj
clojure
[org.clojure/spec.alpha "0.3.214"] [sablono "0.4.0"] just to download [com.datomic/simulant "0.1.8"] ; just to download just to download [com.cognitect/transit-cljs "0.8.232"] ; just to download [datascript "0.13.1"] ; just to download may require reversion to old version [figwheel-sidecar "0.5.0-SNAPSHOT" :scope "t...
(defproject snergly "0.1.0-SNAPSHOT" :description "Maze algorithms in Clojure (from Jamis Buck's /Mazes for Programmers/ book)" :url "" :license {:name "Eclipse Public License" :url "-v10.html"} :main ^:skip-aot snergly.core :dependencies [[org.clojure/clojure "1.10.3"] [org.cloju...
58fdd780b7e64944db21e1a3422f2782f11843a902658cd2abb17c51d944b7ea
patoline/patoline
hyphen.ml
open Unicodelib open UChar open UCharInfo type ptree = | Node of string * ptree UMap.t | Exce of string list * ptree UMap.t let empty = Node ("", UMap.empty) let find u m = try UMap.find u m with Not_found -> empty let is_num c = c >= int_of_char '0' && c <= int_of_char '9' let insert tree a = let...
null
https://raw.githubusercontent.com/patoline/patoline/3dcd41fdff64895d795d4a78baa27d572b161081/cesure/hyphen.ml
ocaml
Pattern is already an exception | Mc | Me | Mn
open Unicodelib open UChar open UCharInfo type ptree = | Node of string * ptree UMap.t | Exce of string list * ptree UMap.t let empty = Node ("", UMap.empty) let find u m = try UMap.find u m with Not_found -> empty let is_num c = c >= int_of_char '0' && c <= int_of_char '9' let insert tree a = let...
652c48b1c885a5ceaa050d4c827852519efb8ff9ca354ffe94e97032caa54d9d
TyOverby/mono
global_listeners.ml
open Js_of_ocaml module Make (X : sig val event_kind : Dom_html.mouseEvent Js.t Dom.Event.typ end) = struct include Hooks.Make (struct module Input = struct type t = Dom_html.mouseEvent Js.t -> unit Ui_effect.t [@@deriving sexp_of] let combine f g event = Ui_effect.Many [ f event; g even...
null
https://raw.githubusercontent.com/TyOverby/mono/8d6b3484d5db63f2f5472c7367986ea30290764d/vendor/janestreet-virtual_dom/src/global_listeners.ml
ocaml
if the callback function changes, cancel the old one and re-install
open Js_of_ocaml module Make (X : sig val event_kind : Dom_html.mouseEvent Js.t Dom.Event.typ end) = struct include Hooks.Make (struct module Input = struct type t = Dom_html.mouseEvent Js.t -> unit Ui_effect.t [@@deriving sexp_of] let combine f g event = Ui_effect.Many [ f event; g even...
3e559ebe7ff0e96d398056a8608eccc389ae161fda6eb575212123c05d14a264
txyyss/Project-Euler
Euler063.hs
The 5 - digit number , 16807=7 ^ 5 , is also a fifth power . Similarly , the 9 - digit number , 134217728=8 ^ 9 , is a ninth power . -- How many n-digit positive integers exist which are also an nth -- power? module Euler063 where import Data.List result063 = length . nub $ sort [nk | n<-[1..9], k <-[1..21], le...
null
https://raw.githubusercontent.com/txyyss/Project-Euler/d2f41dad429013868445c1c9c1c270b951550ee9/Euler063.hs
haskell
How many n-digit positive integers exist which are also an nth power?
The 5 - digit number , 16807=7 ^ 5 , is also a fifth power . Similarly , the 9 - digit number , 134217728=8 ^ 9 , is a ninth power . module Euler063 where import Data.List result063 = length . nub $ sort [nk | n<-[1..9], k <-[1..21], let nk = n^k, length (show nk) == k]
5e52b78f8c268f9168f737ff9e73504ad621bb3a740802fde2d045bce9946419
input-output-hk/cardano-wallet-legacy
Generator.hs
# LANGUAGE TemplateHaskell # # LANGUAGE TupleSections # module Wallet.Inductive.Generator ( -- * Wallet event tree -- ** Parameters GenEventsParams(..) , defEventsParams -- ** State , GenEventsGlobalState(..) , gegsNextHash , gegsPending , initEventsGlobalState -- ** Generator , GenE...
null
https://raw.githubusercontent.com/input-output-hk/cardano-wallet-legacy/143e6d0dac0b28b3274600c6c49ec87e42ec9f37/test/unit/Wallet/Inductive/Generator.hs
haskell
* Wallet event tree ** Parameters ** State ** Generator * Wallet events ------------------------------------------------------------------------------ Wallet event tree ------------------------------------------------------------------------------ | Set of transactions, indexed by their given hash We can do t...
# LANGUAGE TemplateHaskell # # LANGUAGE TupleSections # module Wallet.Inductive.Generator ( GenEventsParams(..) , defEventsParams , GenEventsGlobalState(..) , gegsNextHash , gegsPending , initEventsGlobalState , GenEvents , genEventTree , genWalletEvents ) where import Universum im...
2d0a32e32cb1f206ddc1a3f8e6c9d1825b91efd9052f2573a3e8f9a51b4013e4
metaocaml/ber-metaocaml
pr7016.ml
(* TEST * expect *) type (_, _) t = | Nil : ('tl, 'tl) t | Cons : 'a * ('b, 'tl) t -> ('a * 'b, 'tl) t;; warn , cf PR#6993 [%%expect{| type (_, _) t = Nil : ('tl, 'tl) t | Cons : 'a * ('b, 'tl) t -> ('a * 'b, 'tl) t Line 5, characters 9-43: warn , cf PR#6993 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^...
null
https://raw.githubusercontent.com/metaocaml/ber-metaocaml/4992d1f87fc08ccb958817926cf9d1d739caf3a2/testsuite/tests/typing-gadts/pr7016.ml
ocaml
TEST * expect ok ok
type (_, _) t = | Nil : ('tl, 'tl) t | Cons : 'a * ('b, 'tl) t -> ('a * 'b, 'tl) t;; warn , cf PR#6993 [%%expect{| type (_, _) t = Nil : ('tl, 'tl) t | Cons : 'a * ('b, 'tl) t -> ('a * 'b, 'tl) t Line 5, characters 9-43: warn , cf PR#6993 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Warning 8: this p...
9068e538ddd405305a4b2a20d51652a90d2ff24370139e12944f98ef2cd5eabc
clash-lang/clash-compiler
NetlistTypes.hs
| Copyright : ( C ) 2013 - 2016 , University of Twente , 2016 - 2017 , Myrtle Software Ltd , 2021 - 2022 , QBayLogic B.V. License : BSD2 ( see the file LICENSE ) Maintainer : QBayLogic B.V. < > Copyright : (C) 2013-2016, University of Twe...
null
https://raw.githubusercontent.com/clash-lang/clash-compiler/ba4765139ea0728546bf934005d2d9b77e48d8c7/clash-ghc/src-ghc/Clash/GHC/NetlistTypes.hs
haskell
# LANGUAGE OverloadedStrings # begin an arbitrarily large, runtime sized construct). ^ Custom bit representations ^ Type constructor map returnN :: HWType -> constructor fields. constructor fields. never end up being used in the generated HDL. ^ Name of type (for error reporting) ^ [(Fully qualified constructo...
| Copyright : ( C ) 2013 - 2016 , University of Twente , 2016 - 2017 , Myrtle Software Ltd , 2021 - 2022 , QBayLogic B.V. License : BSD2 ( see the file LICENSE ) Maintainer : QBayLogic B.V. < > Copyright : (C) 2013-2016, University of Twe...
0b6b5b416c4b0c6bcfa74fff7f90f714363a50e0f73b3c3b9f942a467d3a16b4
Stratus3D/programming_erlang_exercises
processes_graph.erl
-module(processes_graph). -export([generate_data/3, spawn_and_time/1]). % generate_data(OutputFilename, End, Step) % % Invoke spawn_and_time/1 repeatedly with an number that increases by `Step` % until `End` is reached. Write the resulting times to the file specified as % `OutputFilename` formatted as CSV. % % Exampl...
null
https://raw.githubusercontent.com/Stratus3D/programming_erlang_exercises/e4fd01024812059d338facc20f551e7dff4dac7e/chapter_12/exercise_2/processes_graph.erl
erlang
generate_data(OutputFilename, End, Step) Invoke spawn_and_time/1 repeatedly with an number that increases by `Step` until `End` is reached. Write the resulting times to the file specified as `OutputFilename` formatted as CSV. Example the runtime and wall block time.
-module(processes_graph). -export([generate_data/3, spawn_and_time/1]). processes_graph : generate_data("data.csv " , 50 , 25 ) . generate_data(OutputFilename, End, Step) when is_integer(End), is_integer(Step) -> {ok, File} = file:open(OutputFilename, [write]), Start = 1, Steps = lists:seq(Start, End +...
c305868a109519f84113dcd93aa66c4851a8255c995d260415b1c7750367a93c
basho/enm
enm_bus.erl
%% ------------------------------------------------------------------- %% %% enm_bus: test bus protocol for enm %% Copyright ( c ) 2014 Basho Technologies , Inc. All Rights Reserved . %% This file is provided to you under the Apache License , %% Version 2.0 (the "License"); you may not use this file except in c...
null
https://raw.githubusercontent.com/basho/enm/0c8a047ebda77e35fc9c514585e7a523a3fc8cfa/test/enm_bus.erl
erlang
------------------------------------------------------------------- enm_bus: test bus protocol for enm Version 2.0 (the "License"); you may not use this file a copy of the License at -2.0 Unless required by applicable law or agreed to in writing, KIND, either express or implied. See the License for the ...
Copyright ( c ) 2014 Basho Technologies , Inc. All Rights Reserved . This file is provided to you under the Apache License , except in compliance with the License . You may obtain software distributed under the License is distributed on an " AS IS " BASIS , WITHOUT WARRANTIES OR CONDITIONS OF ANY -module(...
44043573b3ba3771d5390705ad6760ffcc1562aa41c035dd2b7c408eb17f6043
ygrek/mldonkey
donkeyProtoClient.ml
Copyright 2001 , 2002 b8_bavard , b8_fee_carabine , This file is part of mldonkey . mldonkey is free software ; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation ; either version 2 of the License , or ...
null
https://raw.githubusercontent.com/ygrek/mldonkey/e136e7436c7d0f47f7222e43daa56ed721d12b0e/src/networks/donkey/donkeyProtoClient.ml
ocaml
emule_miscoptions1 emule_miscoptions2 dec: [(96)(215)(1)(0)(0)(0)(0)(0)(0)(0)(0)(0)(0)] OP_QUEUERANKING: int16 CURRENT_VERSION_SHORT = !!emule_protocol_version lprintf "PER SOURCES LEN: %d\n" slen; lprintf "Emule magic: %d opcode %d:" magic opcode; lprint_newline (); dump s; lprint_newlin...
Copyright 2001 , 2002 b8_bavard , b8_fee_carabine , This file is part of mldonkey . mldonkey is free software ; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation ; either version 2 of the License , or ...
dfd56c5f26f44a88d9d548ea3ee731220b8f1cc08273271d410beb0acf1c2d37
nikita-volkov/rerebase
Vector.hs
module Data.Vector ( module Rebase.Data.Vector ) where import Rebase.Data.Vector
null
https://raw.githubusercontent.com/nikita-volkov/rerebase/25895e6d8b0c515c912c509ad8dd8868780a74b6/library/Data/Vector.hs
haskell
module Data.Vector ( module Rebase.Data.Vector ) where import Rebase.Data.Vector
b8c9d9351814066981712807fab497448b97b7c8be0308802f332474ec8f0a9a
blindglobe/clocc
queues-package.lisp
;;; -*- Mode: Lisp -*- ;;; queues-package.lisp -- Simple queues in the and style . ;;; Package definition file (in CLtL2 style). ;;; Author : ;;; Copyright ( c ) 1992 - 2000 . All rights reserved . ;;; This software is released under the terms of the GNU Lesser General ;;; Public License (LGPL, see file C...
null
https://raw.githubusercontent.com/blindglobe/clocc/a50bb75edb01039b282cf320e4505122a59c59a7/src/ext/queues/queues-package.lisp
lisp
-*- Mode: Lisp -*- queues-package.lisp -- Package definition file (in CLtL2 style). This software is released under the terms of the GNU Lesser General Public License (LGPL, see file COPYRIGHT for details). ============================================================================ end of file -- queues-packag...
Simple queues in the and style . Author : Copyright ( c ) 1992 - 2000 . All rights reserved . QUEUES Package (defpackage "CL.UTIL.QUEUES" (:use "COMMON-LISP") (:nicknames "QUEUES") (:shadow common-lisp:first common-lisp:last) (:export "QUEUE" "EMPTY-QUEUE" "MAKE-QUEUE" "SIZE" ...
c2182fe462500a2d347dd67f1a244d792134e160d3127a7055a842b821586c74
40ants/defmain
defmain.lisp
(defpackage defmain-test (:use #:cl #:defmain #:rove #:hamcrest/rove) (:import-from #:defmain #:help)) (in-package defmain-test) (deftest test-map-fields (testing "Checking if map-fields calls function for each fields and adds a help field." (testing "Simple case,...
null
https://raw.githubusercontent.com/40ants/defmain/bf1f88c9a103b3bfbf98f295caf1e50a67ea3717/t/defmain.lisp
lisp
(defpackage defmain-test (:use #:cl #:defmain #:rove #:hamcrest/rove) (:import-from #:defmain #:help)) (in-package defmain-test) (deftest test-map-fields (testing "Checking if map-fields calls function for each fields and adds a help field." (testing "Simple case,...
f3010c25d609a7e30233e9f76954ddde82b39488ea609843863d6920c754c846
iijlab/postgresql-pure
Person.hs
{-# LANGUAGE DataKinds #-} {-# LANGUAGE DeriveGeneric #-} # LANGUAGE FlexibleInstances # # LANGUAGE MultiParamTypeClasses # {-# LANGUAGE TemplateHaskell #-} module Relation.Pure.Person where import DataSource.Pure (connect) import Prelude ...
null
https://raw.githubusercontent.com/iijlab/postgresql-pure/2a640f102f3e3540aedbcf4cfb5d1ed10310f773/test-relational-record/Relation/Pure/Person.hs
haskell
# LANGUAGE DataKinds # # LANGUAGE DeriveGeneric # # LANGUAGE TemplateHaskell #
# LANGUAGE FlexibleInstances # # LANGUAGE MultiParamTypeClasses # module Relation.Pure.Person where import DataSource.Pure (connect) import Prelude (Show) import Database.HDBC.Query.TH (defineTableFromDB) import Database.H...